/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.context;

import java.util.Locale;

import org.apache.struts.Globals;

import org.jdesigner.platform.core.threadlocal.ThreadLocalProperties;
import org.jdesigner.platform.web.WebConstants;
import org.jdesigner.platform.web.theme.Theme;

import org.jdesigner.application.template.domain.MenuLocation;
import org.jdesigner.application.template.domain.UserLogin;
import org.jdesigner.application.template.service.MenuService;
import org.jdesigner.application.template.service.SecurityService;

/**
 * <b>ThreadLocalContext</b>
 * 
 * <p>ThreadLocalProperties 에 설정된 서브 시스템 전달 가능한 변수</p>
 * 
 * @author leesangboo
 * 
 */
public class ThreadLocalContext {

	/**
	 * Return UserLogin in current thread.
	 * 
	 * @return
	 */
	public static UserLogin getUserLogin() {
		return (UserLogin) ThreadLocalProperties.get(SecurityService.THREAD_LOCAL_USER_LOGIN_KEY);
	}

	/**
	 * Return MenuLocation in current thread.
	 * 
	 * @return
	 */
	public static MenuLocation getMenuLocation() {
		return (MenuLocation) ThreadLocalProperties.get(MenuService.MENU_LOCATION_KEY);
	}

	/**
	 * Return Theme in current thread.
	 * 
	 * @return
	 */
	public static Theme getTheme() {
		return (Theme) ThreadLocalProperties.get(WebConstants.THEME_KEY);
	}

	/**
	 * Return Locale in current thread.
	 * 
	 * @return
	 */
	public static Locale getLocale() {
		return (Locale) ThreadLocalProperties.get(Globals.LOCALE_KEY);
	}

}
