/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.util.DateUtils;

/**
 * AnalysisDAO
 * 
 * @author leesangboo
 * 
 */
public class AnalysisDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(AnalysisDAO.class);

	/**
	 * CodeDAO
	 */
	public AnalysisDAO() {
		log.debug("init..."); //
	}

	/**
	 * 기간에 해당하는 접속 카운트를 반환한다.
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 * @return
	 * @throws DatabaseException
	 */
	public Page selectAccessAnalysisPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectAccessAnalysisPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	/**
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 * @return
	 * @throws DatabaseException
	 */
	public Page selectMonitoringLogPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectMonitoringLogPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	/**
	 * 기간에 해당하는 페이지뷰 카운트를 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public List selectPageViewCountList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectPageViewCount.xml", params);
		return query.execute().selectList();
	}

	/**
	 * 기간에 해당하는 접속 카운트를 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public List selectAccessCountList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectAccessCount.xml", params);
		return query.execute().selectList();
	}

	/**
	 * 기간에 해당하는 로그인 카운트를 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public List selectLoginCountList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectLoginCount.xml", params);
		return query.execute().selectList();
	}

	/**
	 * 파일 업로드 크기 맵을 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public Map selectFileUploadSizeMap(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectFileUploadSize.xml", params);
		return query.execute().selectMap();
	}

	/**
	 * 코드 그룹을 입력한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void insertAccessAnalysis(Map params) throws DatabaseException {
		params.put("insert_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_ACCESS_ANALYSIS", params);
		query.execute().insert();
	}

	/**
	 * 시스템 로그 페이지를 반환한다.
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 * @return
	 * @throws DatabaseException
	 */
	public Page selectSystemLogPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectSystemLogPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	public List selectSystemLogByProcessID(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectSystemLogByProcessID.xml", params);
		return query.execute().selectList();
	}

	/**
	 * 시스템 로그 카테고리를 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public List selectSystemLogDayCategoryList(Map params) throws DatabaseException {
		List day_list = new ArrayList();
		String term = (String) params.get("term");

		Iterator iter = null;
		if (term.equals("RANGE_WEEK_SUNDAY")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_SUNDAY);
		} else if (term.equals("RANGE_WEEK_CENTER")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_CENTER);
		} else if (term.equals("RANGE_MONTH_SUNDAY")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_MONTH_SUNDAY);
		} else {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_SUNDAY);
		}

		while (iter.hasNext()) {
			Date current_date = ((Calendar) iter.next()).getTime();
			Map result = new HashMap();
			java.text.SimpleDateFormat format = new java.text.SimpleDateFormat("MM/dd");
			result.put("day", format.format(current_date));
			result.put("log_count", new Long(0));
			day_list.add(result);
		}

		return day_list;
	}

	/**
	 * 시스템 로그 카운트를 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public List selectSystemLogCountList(Map params) throws DatabaseException {
		List countList = new ArrayList();
		String term = (String) params.get("term");

		Iterator iter = null;
		if (term.equals("RANGE_WEEK_SUNDAY")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_SUNDAY);
		} else if (term.equals("RANGE_WEEK_CENTER")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_CENTER);
		} else if (term.equals("RANGE_MONTH_SUNDAY")) {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_MONTH_SUNDAY);
		} else {
			iter = org.apache.commons.lang.time.DateUtils.iterator(new java.util.Date(), org.apache.commons.lang.time.DateUtils.RANGE_WEEK_SUNDAY);
		}

		while (iter.hasNext()) {

			Date current_date = ((Calendar) iter.next()).getTime(); //

			Map new_params = new HashMap(params);
			new_params.put("current_date", DateUtils.dateToISO(current_date, true));
			NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.selectSystemLogCount.xml", new_params);
			Map result = query.execute().selectMap();
			if (result != null && !result.isEmpty()) {
				countList.add(result);
			} else {
				result = new HashMap();
				java.text.SimpleDateFormat format = new java.text.SimpleDateFormat("MM/dd");
				result.put("day", format.format(current_date));
				result.put("log_count", new Long(0));
				countList.add(result);
			}
		}
		log.info(countList);
		return countList;
	}

	public void deleteSystemLogByScheduler(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.deleteSystemLogByScheduler.xml", params);
		query.execute().update();
	}

	public void deleteAccessAnalysisByScheduler(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/AnalysisDAO.deleteAccessAnalysisByScheduler.xml", params);
		query.execute().update();
	}

	public void insertMonitoringLog(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_MONITORING_LOG", params);
		query.addParameter("insert_date", new Timestamp(new Date().getTime()));
		query.execute().insert();
	}

}
