/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpSession;

import org.jdesigner.platform.data.Page;

import org.jdesigner.application.template.domain.UserLogin;

/**
 * <B>보안 서비스</B>
 * 
 * @author leesangboo
 * 
 */
public interface SecurityService {

	//
	public static final String THREAD_LOCAL_USER_LOGIN_KEY = "org.jdesigner.platform.application.template.security.USER_LOGIN";

	//
	public static final String EVENT_LOGIN_TYPE = "LOGIN";

	//
	public static final String EVENT_LOGOUT_TYPE = "LOGOUT";

	/**
	 * 인증 여부를 확인한다.
	 * 
	 * @return
	 */
	public boolean isUserAuthenticated();

	/**
	 * 사용자 로그인을 반환한다.
	 * 
	 * @return UserLogin
	 */
	public UserLogin getUserLogin();

	/**
	 * 세션에서 사용자 로그인을 반환한다.
	 * 
	 * @param session
	 * @return
	 */
	public UserLogin getUserLoginFromSession(HttpSession session);

	/**
	 * 사용자의 롤을 반환한다.
	 * 
	 * @return ArrayList roles
	 */
	public ArrayList getRoles();

	/**
	 * 사용자가 롤을 가지고 있는지 확인한다.
	 * 
	 * @param role
	 * @return true if user has the role
	 */
	public boolean isUserInRole(String role);

	/**
	 * 사용자가 롤을 가지고 있는지 확인한다.
	 * 
	 * @param roles
	 * @return true if user has the roles
	 */
	public boolean isUserInRoles(List roles);

	/**
	 * 패스워드를 암호화한다.
	 * 
	 * @param password
	 * @return
	 */
	public String encryptPassword(String password);

	/**
	 * 패스워드를 복호화한다.
	 * 
	 * @param password
	 * @return
	 */
	public String decryptPassword(String password);

	/**
	 * 로그인 이벤트 리스너를 반환한다.
	 * 
	 * @return
	 * @throws CommonServiceException
	 */
	public LoginEventListener getLoginEventListener() throws CommonServiceException;

	/**
	 * 로그인을 실행한다.
	 * 
	 * @param ip
	 * @param username
	 * @param password
	 * @return
	 */
	public boolean login(HttpSession session, String ip, String username, String password);

	/**
	 * 로그아웃을 실행한다.
	 */
	public void logout(HttpSession session);

	/**
	 * 사용자 로그인을 등록한다.
	 * 
	 * @param ip
	 * @param username
	 * @param password
	 */
	public void setUserLogin(HttpSession session, String ip, String username, String password);

	/**
	 * 권한 그룹을 조회한다.
	 * 
	 * @return
	 * @throws CommonServiceException
	 */
	public Page selectAuthGroupPage(Map params, int start, int range, String sort, boolean desc) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @return
	 * @throws CommonServiceException
	 */
	public List selectAuthGroupRoleList(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @return
	 * @throws CommonServiceException
	 */
	public Map selectAuthGroup(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @param auth_role_list
	 * @throws CommonServiceException
	 */
	public void insertAuthGroup(Map params, List auth_role_list) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @param auth_role_list
	 * @throws CommonServiceException
	 */
	public void updateAuthGroup(Map params, List auth_role_list) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @throws CommonServiceException
	 */
	public void deleteAuthGroup(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 * @return
	 * @throws CommonServiceException
	 */
	public Page selectAuthRolePage(Map params, int start, int range, String sort, boolean desc) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @return
	 * @throws CommonServiceException
	 */
	public Map selectAuthRole(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @throws CommonServiceException
	 */
	public void insertAuthRole(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @throws CommonServiceException
	 */
	public void updateAuthRole(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @throws CommonServiceException
	 */
	public void deleteAuthRole(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @return
	 * @throws CommonServiceException
	 */
	public Map selectUserLoginHistoryByLast(Map params) throws CommonServiceException;

	/**
	 * 
	 * @param params
	 * @throws CommonServiceException
	 */
	public void insertLoginHistory(Map params) throws CommonServiceException;
}
