/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.service.config;

import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dom4j.Document;
import org.dom4j.Node;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.Dom4jUtils;

import org.jdesigner.application.template.domain.SecurityAccessRule;

/**
 * SecurityConfigurationLoader
 * 
 * @author leesangboo
 * 
 */
public class SecurityConfigurationLoader {

	private static final Log log = LogFactory.getLog(SecurityConfigurationLoader.class);

	private static final String RULE_NODE_XPATH = "/security-config/rule";

	private static class SecurityConfigFactoryHolder {
		static SecurityConfigurationLoader instance = new SecurityConfigurationLoader();
	}

	public static SecurityConfigurationLoader getInstance() {
		return SecurityConfigFactoryHolder.instance;
	}

	/**
	 * 
	 * @param filePath
	 * @return
	 */
	public List load(String filePath) {
		List securityAccessRuleList = new ArrayList();
		try {

			log.info("Security filter configuration loading...");

			log.info("Security filter configuration xml file : path=[" + filePath + "]");

			String appPath = ApplicationContextFactory.getInstance().getApplicationContext().getAppPath();
			File configFile = new File(appPath, filePath);

			Document document = Dom4jUtils.getXmlDocument(configFile);
			List nodeList = document.selectNodes(RULE_NODE_XPATH);
			for (int i = 0; i < nodeList.size(); i++) {
				Node node = (Node) nodeList.get(i);

				String url = node.valueOf("@" + "url-pattern");
				boolean all = Boolean.parseBoolean(node.valueOf("@" + "all") != null ? node.valueOf("@" + "all") : "false");
				boolean login = Boolean.parseBoolean(node.valueOf("@" + "login") != null ? node.valueOf("@" + "login") : "false");
				List roles = Arrays.asList(node.valueOf("@" + "roles").split(","));

				SecurityAccessRule securityAccessRule = new SecurityAccessRule(url, all, login, roles);
				securityAccessRuleList.add(securityAccessRule);
			}
		} catch (Exception ex) {
			String msg = "Cannot parse security config xml document : " + ex.getMessage();
			log.error(msg, ex);
		}
		return securityAccessRuleList;
	}

}
