/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.DataMap;
import org.jdesigner.platform.data.Tree;
import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.util.PatternMatchUtils;

import org.jdesigner.application.template.dao.MenuDAO;
import org.jdesigner.application.template.domain.MenuLocation;
import org.jdesigner.application.template.service.CommonServiceException;
import org.jdesigner.application.template.service.MenuService;
import org.jdesigner.application.template.service.factory.MenuSingletoneFactory;
import org.jdesigner.application.template.web.WebKeys;

/**
 * <B>메뉴 서비스 구현자</B>
 * 
 * @author leesangboo
 * 
 */
public class MenuServiceImpl implements MenuService {

	private static final Log log = LogFactory.getLog(MenuServiceImpl.class);

	private MenuDAO dao;

	/**
	 * MenuServiceImpl
	 */
	public MenuServiceImpl() {
		dao = new MenuDAO();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# selectFullMenuTreeList()
	 */
	public List selectAllMenuTreeList() throws CommonServiceException {
		List menuTreeList = null;
		MenuSingletoneFactory factory = MenuSingletoneFactory.getInstance();
		if (factory.getMenuTreeList() == null) {
			menuTreeList = selectFullMenuTreeList();
			factory.setMenuTreeList(menuTreeList);
			log.info("All application menus are cached : size=[" + menuTreeList.size() + "]");
		} else {
			menuTreeList = factory.getMenuTreeList();
		}
		return menuTreeList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.MenuService#selectFullMenuTreeList()
	 */
	public List selectFullMenuTreeList() throws CommonServiceException {
		return dao.selectFullMenuTreeList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# selectMenuTreeByUsername(java.util.Map)
	 */
	public Tree selectMenuTreeByUsername(Map params) throws CommonServiceException {
		return dao.selectMenuTreeByUsername(params);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# getMenuSelectedInSession(javax.servlet.http.HttpSession)
	 */
	public MenuLocation getSelectedMenuLocationInSession(HttpSession session) throws CommonServiceException {
		return (MenuLocation) session.getAttribute(WebKeys.USER_CURRENT_MENU_LOCATION_KEY);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# hasMenuSelectedInSession(javax.servlet.http.HttpSession)
	 */
	public boolean hasSelectedMenuLocationInSession(HttpSession session) throws CommonServiceException {
		return (session.getAttribute(WebKeys.USER_CURRENT_MENU_LOCATION_KEY) == null) ? false : true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#getMenuSelectedRuleList ()
	 */
	public List getMenuSelectedRuleList() throws CommonServiceException {
		// MenuSelectedConfigFactory factory =
		// MenuSelectedConfigFactory.getInstance();
		// return factory.getMenuSelectedRuleList();
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#selectMenuByURL(java .lang.String)
	 */
	public Map selectMenuByURL(String url) throws CommonServiceException {
		return dao.selectMenuByURL(url);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#getMenuSelectedRule( java.lang.String)
	 */
	public MenuLocation getMenuLocationByURL(String url, String query) throws CommonServiceException {

		//
		MenuSingletoneFactory factory = MenuSingletoneFactory.getInstance();
		Map selectedMenuMap = factory.getSelectedMenuMap();

		if (selectedMenuMap != null && selectedMenuMap.containsKey(url + query)) {
			//
			return (MenuLocation) selectedMenuMap.get(url + query);

		} else {

			//
			MenuLocation menuLocation = null;
			//
			DataMap currentMenuDataMap = null;
			//
			List allMenuTreeList = selectAllMenuTreeList();

			//
			if (allMenuTreeList == null || allMenuTreeList.size() == 0) {
				log.warn("Menu size is 0, Please must be setting menus.");
			}

			// URI + Query
			for (int i = 0; allMenuTreeList != null && i < allMenuTreeList.size(); i++) {
				DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
				String pattern = menuDataMap.getString("href_link");
				boolean isMatch = PatternMatchUtils.simpleMatch(pattern, url + query);
				if (isMatch) {
					currentMenuDataMap = menuDataMap;
					break;
				}
			}

			// URI
			if (currentMenuDataMap == null) {
				for (int i = 0; allMenuTreeList != null && i < allMenuTreeList.size(); i++) {
					DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
					String pattern = menuDataMap.getString("href_link");
					boolean isMatch = PatternMatchUtils.simpleMatch(pattern, url);
					if (isMatch) {
						currentMenuDataMap = menuDataMap;
						break;
					}
				}
			}

			// PATTERN
			if (currentMenuDataMap == null) {
				for (int i = 0; allMenuTreeList != null && i < allMenuTreeList.size(); i++) {
					DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
					String patterns = menuDataMap.getString("category_href_link_pattern");
					String[] patternArray = patterns.split(",");
					boolean isMatch = PatternMatchUtils.simpleMatch(patternArray, url + query);
					if (isMatch) {
						currentMenuDataMap = menuDataMap;
						break;
					}
				}
			}

			// Menu Location Setting
			if (currentMenuDataMap != null) {

				int menu_level = currentMenuDataMap.getBigDecimal("menu_level").intValue();

				menuLocation = new MenuLocation();
				menuLocation.setUrl(url + query);
				menuLocation.setCurrentLevel(menu_level);
				menuLocation.setCurrentMenu(currentMenuDataMap);

				if (menu_level == 1) {
					log.debug("Menu selected level : [1]");
					menuLocation.setPrimaryMenu(currentMenuDataMap);
				}

				if (menu_level == 2) {
					log.debug("Menu selected level : [2]");
					menuLocation.setSecondMenu(currentMenuDataMap);
					// 1
					String primaryMenuCode = currentMenuDataMap.getString("parent_menu_code");
					DataMap primaryMenuMap = null;
					for (int i = 0; i < allMenuTreeList.size(); i++) {
						DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
						if (primaryMenuCode.equals(menuDataMap.get("menu_code"))) {
							primaryMenuMap = menuDataMap;
							menuLocation.setPrimaryMenu(primaryMenuMap);
							break;
						}
					}

				}
				if (menu_level == 3) {
					log.debug("Menu selected level : [3]");
					menuLocation.setThirdMenu(currentMenuDataMap);
					// 2
					String secondMenuCode = currentMenuDataMap.getString("parent_menu_code");
					DataMap secondMenuMap = null;
					for (int i = 0; i < allMenuTreeList.size(); i++) {
						DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
						if (secondMenuCode.equals(menuDataMap.get("menu_code"))) {
							secondMenuMap = menuDataMap;
							menuLocation.setSecondMenu(secondMenuMap);
							break;
						}
					}

					// 1
					String primaryMenuCode = secondMenuMap.getString("parent_menu_code");
					DataMap primaryMenuMap = null;
					for (int i = 0; i < allMenuTreeList.size(); i++) {
						DataMap menuDataMap = (DataMap) allMenuTreeList.get(i);
						if (primaryMenuCode.equals(menuDataMap.get("menu_code"))) {
							primaryMenuMap = menuDataMap;
							menuLocation.setPrimaryMenu(primaryMenuMap);
							break;
						}
					}

				}

				// Singleton cache
				if (selectedMenuMap == null) {
					selectedMenuMap = new HashMap();
				}
				//
				selectedMenuMap.put(url + query, menuLocation);
				factory.setSelectedMenuMap(selectedMenuMap);
				//
				log.debug("Menu selected is saved : map=[" + selectedMenuMap + "]");

			} else {
				//
				log.debug("Menu match not found : uri=[" + url + query + "]");
			}

			return menuLocation;
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#selectPrimaryMenuList()
	 */
	public List selectPrimaryMenuList() throws CommonServiceException {
		// final String key = "primary";
		// if(cache.get(key) == null){
		List list = dao.selectPrimaryMenuList();
		// cache.put(key, list);
		// log.info("Primary menu is cached.");
		// }
		// return (List) cache.get(key);
		return list;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#selectSecondMenuList (java.lang.String)
	 */
	public List selectSecondMenuList(String parent_menu_code) throws CommonServiceException {
		// final String key = "second_" + parent_menu_code;
		// if(cache.get(key) == null){
		List list = dao.selectSecondMenuList(parent_menu_code);
		// cache.put(key, list);
		// log.info("Second menu is cached.");
		// }
		// return (List) cache.get(key);
		return list;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#selectThirdMenuList( java.lang.String)
	 */
	public List selectThirdMenuList(String parent_menu_code) throws CommonServiceException {
		// final String key = "third_" + parent_menu_code;
		// if(cache.get(key) == null){
		List list = dao.selectThirdMenuList(parent_menu_code);
		// cache.put(key, list);
		// log.info("Third menu is cached.");
		// }
		// return (List) cache.get(key);
		return list;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#selectMenu(java.util .Map)
	 */
	public Map selectMenu(Map params) throws CommonServiceException {
		return dao.selectMenu(params);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#insertMenu(java.util .Map)
	 */
	public void insertMenu(Map params, List auth_role_list) throws CommonServiceException {
		dao.insertMenu(params, auth_role_list);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#updateMenu(java.util .Map)
	 */
	public void updateMenu(Map params, List auth_role_list) throws CommonServiceException {
		dao.updateMenu(params, auth_role_list);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.doosan.oracle.ebs.common.service.MenuService#deleteMenu(java.util .Map)
	 */
	public void deleteMenu(Map params) throws CommonServiceException {
		dao.deleteMenu(params);
	}

	public List selectMenuTreeList(Map params) throws DatabaseException {
		return dao.selectMenuTreeList(params);
	}

	public List selectMenuLevelList(Map params) throws DatabaseException {
		return dao.selectMenuLevelList(params);
	}

	public List selectMenuTreeRoleList(Map params) throws CommonServiceException {
		return dao.selectMenuTreeRoleList(params);
	}

	public Map selectMenuTreeRole(Map params) throws CommonServiceException {
		// TODO Auto-generated method stub
		return null;
	}

	public void deleteMenuTreeRole(Map params) throws CommonServiceException {
		// TODO Auto-generated method stub

	}

	public void insertMenuTreeRole(Map params) throws CommonServiceException {
		// TODO Auto-generated method stub

	}

	public void updateMenuTreeRole(Map params) throws CommonServiceException {
		// TODO Auto-generated method stub
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# selectPrimaryMenuListByUsername(javax.servlet.http.HttpSession)
	 */
	public List selectPrimaryMenuListByUsername(HttpSession session) throws CommonServiceException {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# selectSecondMenuListByUsername(javax.servlet.http.HttpSession, java.lang.String)
	 */
	public List selectSecondMenuListByUsername(HttpSession session, String parentMenuCode) throws CommonServiceException {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# selectThirdMenuListByUsername(javax.servlet.http.HttpSession, java.lang.String)
	 */
	public List selectThirdMenuListByUsername(HttpSession session, String parentMenuCode) throws CommonServiceException {
		// TODO Auto-generated method stub
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.MenuService# resetMenuSingletoneFactory()
	 */
	public void resetMenuSingletoneFactory() throws CommonServiceException {
		MenuSingletoneFactory factory = MenuSingletoneFactory.getInstance();
		factory.reset();
	}

}
