/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import java.util.List;
import java.util.Map;

import org.jdesigner.platform.data.Page;

import org.jdesigner.application.template.dao.UserDAO;
import org.jdesigner.application.template.service.CommonServiceException;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.SecurityService;
import org.jdesigner.application.template.service.UserService;

/**
 * UserServiceImpl
 * 
 * @author leesangboo
 * 
 */
public class UserServiceImpl implements UserService {

	private SecurityService securityService;

	private UserDAO userDAO;

	public UserServiceImpl() {
		this.securityService = CommonServiceFactory.getSecurityService();
		this.userDAO = new UserDAO();
	}

	public Page selectUserLoginPage(Map params, int start, int range, String sort, boolean desc) throws CommonServiceException {
		return userDAO.selectUserLoginPage(params, start, range, sort, desc);
	}

	public Map selectUserLogin(Map params) throws CommonServiceException {
		Map data = userDAO.selectUserLogin(params);
		String decrypt_password = securityService.decryptPassword((String) data.get("password"));
		data.put("password", decrypt_password);
		return data;
	}

	public void deleteUserLogin(Map params) throws CommonServiceException {
		userDAO.deleteUserLogin(params);
	}

	public void insertUserLogin(Map params, List auth_group_list, List auth_role_list) throws CommonServiceException {
		String encrypt_password = securityService.encryptPassword((String) params.get("password"));
		params.put("password", encrypt_password);
		userDAO.insertUserLogin(params, auth_group_list, auth_role_list);
	}

	public void updateUserLogin(Map params, List auth_group_list, List auth_role_list) throws CommonServiceException {
		String encrypt_password = securityService.encryptPassword((String) params.get("password"));
		params.put("password", encrypt_password);
		userDAO.updateUserLogin(params, auth_group_list, auth_role_list);
	}

	public List selectUserGroupList(Map params) throws CommonServiceException {
		return userDAO.selectUserGroupList(params);
	}

	public List selectUserRoleList(Map params) throws CommonServiceException {
		return userDAO.selectUserRoleList(params);
	}

}
