/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.MDC;

import org.jdesigner.platform.util.StringUtils;

import org.jdesigner.application.template.domain.UserLogin;
import org.jdesigner.application.template.logging.IDGenerator;
import org.jdesigner.application.template.logging.MDCKeys;
import org.jdesigner.application.template.web.WebKeys;

/**
 * MDCFilter
 * 
 * @version 1.0
 */
public class MDCFilter implements Filter {

	public void init(FilterConfig arg0) throws ServletException {
		// 
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)
	 */
	public void doFilter(ServletRequest srequest, ServletResponse sresponse, FilterChain chain) throws IOException, ServletException {
		//
		HttpServletRequest request = (HttpServletRequest) srequest;
		//
		UserLogin user_login = (UserLogin) request.getSession().getAttribute(WebKeys.USER_LOGIN_KEY);
		// Add to MDC of Log4J

		MDC.put(MDCKeys.PROCESS_ID_KEY, IDGenerator.generateProcessID());
		MDC.put(MDCKeys.JSESSION_ID_KEY, StringUtils.replaceNull(request.getSession().getId()));
		MDC.put(MDCKeys.REMORTE_HOST_KEY, StringUtils.replaceNull(request.getRemoteHost()));
		MDC.put(MDCKeys.REMORTE_ADDRESS_KEY, StringUtils.replaceNull(request.getRemoteAddr()));
		MDC.put(MDCKeys.REQUEST_URI_KEY, StringUtils.replaceNull(request.getRequestURI()));
		MDC.put(MDCKeys.REQUEST_QUERY_KEY, StringUtils.replaceNull(request.getQueryString()));
		MDC.put(MDCKeys.USERNAME_KEY, (user_login != null && user_login.getUsername() != null) ? user_login.getUsername() : "");

		//
		chain.doFilter(srequest, sresponse);
	}

	public void destroy() {
		//	
		MDC.remove(MDCKeys.JSESSION_ID_KEY);
		MDC.remove(MDCKeys.REMORTE_HOST_KEY);
		MDC.remove(MDCKeys.REMORTE_ADDRESS_KEY);
		MDC.remove(MDCKeys.REQUEST_URI_KEY);
		MDC.remove(MDCKeys.REQUEST_QUERY_KEY);
		MDC.remove(MDCKeys.USERNAME_KEY);
	}

}
