/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.util.DateUtils;
import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.grid.Grid;

import org.jdesigner.application.template.service.AnalysisService;
import org.jdesigner.application.template.service.CommonCodeService;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 분석 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class AnalysisBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(AnalysisBean.class);

	private CommonCodeService common_code_service;
	private AnalysisService analysis_service;

	private Form search;
	private Form form;
	private Grid grid;

	public AnalysisBean() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		init(); //
	}

	public void init() {
		common_code_service = CommonServiceFactory.getCommonCodeService();
		analysis_service = CommonServiceFactory.getAnalysisService();

		form = new Form();
		search = new Form();
		grid = new Grid();
	}

	public String index() throws Exception {
		search.put("insert_from_date", new Date(System.currentTimeMillis() - DateUtils.ONE_DAY));
		search.put("insert_to_date", new Date());
		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(analysis_service.selectAccessAnalysisPage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String chartPageView() throws Exception {
		//
		Map params = new HashMap();
		String to_date = DateUtils.dateToISO(new java.util.Date());
		params.put("base_date", to_date);
		params.put("minus_day", new Long(7)); // 이전 일주일
		List chart1_view_data = analysis_service.selectPageViewCountList(params);
		//
		super.getRequest().setAttribute("chart1_view_data", chart1_view_data);
		//
		return SUCCESS;
	}

	public String chartAccessCount() throws Exception {
		//
		Map params = new HashMap();
		String to_date = DateUtils.dateToISO(new java.util.Date());
		params.put("base_date", to_date);
		params.put("minus_day", new Long(7)); // 이전 일주일
		List chart1_access_data = analysis_service.selectAccessCountList(params);
		//
		super.getRequest().setAttribute("chart1_access_data", chart1_access_data);
		//
		return SUCCESS;
	}

	public CommonCodeService getCommon_code_service() {
		return common_code_service;
	}

	public void setCommon_code_service(CommonCodeService commonCodeService) {
		this.common_code_service = commonCodeService;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

}
