/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;
import org.jdesigner.platform.web.json.JSONResult;

import org.jdesigner.application.template.service.CommonCodeService;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 그룹코드 관리 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class CommonCodeGroupBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(CommonCodeGroupBean.class);

	private CommonCodeService common_code_service;

	private Form search;
	private Form form;
	private Grid grid;
	private JSONResult json;

	public CommonCodeGroupBean() {
		init(); //
	}

	public void init() {
		//
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		//
		common_code_service = CommonServiceFactory.getCommonCodeService();
		//
		form = new Form();
		search = new Form();
		grid = new Grid();
		json = new JSONResult();
	}

	public void reset() {
		//search.put("test", "test");
	}

	public String index() throws Exception {
		reset();
		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(common_code_service.selectCodeGroupPage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return SUCCESS;
	}

	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(common_code_service.selectCodeGroup(form));
		return (SUCCESS);
	}

	public String insert() throws Exception {
		common_code_service.insertCodeGroup(form);
		setServerMessage("common.insert.success");
		return SUCCESS;
	}

	public String update() throws Exception {
		common_code_service.updateCodeGroup(form);
		setServerMessage("common.update.success");
		return SUCCESS;
	}

	public String delete() throws Exception {
		common_code_service.deleteCodeGroup(form);
		setServerMessage("common.delete.success");
		return SUCCESS;
	}

	public CommonCodeService getCommonCodeService() {
		return common_code_service;
	}

	public void setCommonCodeService(CommonCodeService commonCodeService) {
		this.common_code_service = commonCodeService;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public JSONResult getJson() {
		return json;
	}

	public void setJson(JSONResult json) {
		this.json = json;
	}

}
