/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;
import org.jdesigner.platform.web.table.Table;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.MenuService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 메뉴 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class MenuBean extends TemplateBaseActionBean {

	private static final Log log = LogFactory.getLog(MenuBean.class);

	private static final long serialVersionUID = 1L;

	private MenuService menu_service;

	private Form search;
	private Form form;
	private Grid grid;

	private Table auth_role_table;

	public MenuBean() {
		log.info("Initialize Action Bean : " + this.getClass().getName());
		init(); //
	}

	public void init() {

		menu_service = CommonServiceFactory.getMenuService();

		form = new Form();
		grid = new Grid();
		auth_role_table = new Table();
	}

	public void reset() {
		form = new Form();
	}

	public String index() throws Exception {
		return (SUCCESS);
	}

	public String grid() throws Exception {
		List list = new ArrayList();
		if (form.getString("parent_menu_code").equals("")) {
			list = menu_service.selectPrimaryMenuList();
		} else {
			list = menu_service.selectMenuLevelList(form);
		}
		grid = new Grid(15, list, 0, 99999, "", false);
		return Grid.FORWARD;
	}

	public String resetFullMenu() throws Exception {
		wait(3000); //메뉴 리셋 딜레이 3초
		menu_service.resetMenuSingletoneFactory();
		log.info("Reset menu singletone factory.");
		return (JSON);
	}

	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return SUCCESS;
	}

	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(menu_service.selectMenu(form));
		auth_role_table = new Table(menu_service.selectMenuTreeRoleList(form));
		return (SUCCESS);
	}

	public String insert() throws Exception {
		menu_service.insertMenu(form, auth_role_table);
		super.setServerMessage("common.insert.success");
		reset();
		return SUCCESS;
	}

	public String update() throws Exception {
		menu_service.updateMenu(form, auth_role_table);
		super.setServerMessage("common.update.success");
		init();
		return SUCCESS;
	}

	public String delete() throws Exception {
		menu_service.deleteMenu(form);
		super.setServerMessage("common.delete.success");
		init();
		return SUCCESS;
	}

	public Table getAuth_role_table() {
		return auth_role_table;
	}

	public void setAuth_role_table(Table authRoleTable) {
		auth_role_table = authRoleTable;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public MenuService getMenu_service() {
		return menu_service;
	}

	public void setMenu_service(MenuService menu_service) {
		this.menu_service = menu_service;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

}