/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.data;

import org.jdesigner.platform.util.DateUtils;
import org.jdesigner.platform.util.NumberUtils;

/**
 * <B>Data Converter</B>
 * 
 * @author leesangboo
 * 
 */
public class DataConverter {

	/**
	 * String 값을 해당 유형으로 컨버팅한다.
	 * 
	 * @param typeClass
	 * @param value
	 * @return
	 * @throws DataException
	 */
	public static Object convert(Class typeClass, String value) throws DataException {
		Object convertedValue = null;
		try {

			// 넘버 그룹핑 사용 포맷 및 숫자형인지 체크
			if (isNumberTypeClass(typeClass)) {
				value = removeNumberGroupingUsed(value); //
				if (value != null && !value.equals("") && !org.apache.commons.lang.math.NumberUtils.isNumber(value)) {
					throw new DataException("Invalid numeric value type.");
				}
			}

			// 변환
			if (typeClass == String.class) {
				convertedValue = value;
			} else if (typeClass == int.class || typeClass == Integer.class) {
				convertedValue = new Integer(org.apache.commons.lang.math.NumberUtils.toInt(value));
			} else if (typeClass == long.class || typeClass == Long.class) {
				convertedValue = new Long(org.apache.commons.lang.math.NumberUtils.toLong(value));
			} else if (typeClass == float.class || typeClass == Float.class) {
				convertedValue = new Float(org.apache.commons.lang.math.NumberUtils.toFloat(value));
			} else if (typeClass == double.class || typeClass == Double.class) {
				convertedValue = new Double(org.apache.commons.lang.math.NumberUtils.toDouble(value));
			} else if (typeClass == java.math.BigDecimal.class) {
				convertedValue = org.apache.commons.lang.math.NumberUtils.createBigDecimal(value);
			} else if (typeClass == java.util.Date.class) {
				convertedValue = DateUtils.stringToDate(DataUtils.getDatePattern(), value);
			} else if (typeClass == java.sql.Date.class) {
				convertedValue = DateUtils.stringToSQLDate(DataUtils.getDatePattern(), value);
			} else if (typeClass == java.sql.Timestamp.class) {
				convertedValue = DateUtils.stringToTimestamp(DataUtils.getDateTimePattern(), value);
			} else if (typeClass == java.sql.Time.class) {
				convertedValue = DateUtils.stringToTime(DataUtils.getTimePattern(), value);
			} else {
				throw new DataException("Not support convert class type : " + typeClass);
			}
		} catch (Exception ex) {
			throw new DataException(ex);
		}
		return convertedValue;
	}

	/**
	 * 숫자형 넘버에 그룹핑을 사용했으면 포맷해준다.
	 * 
	 * @param value
	 * @return
	 */
	private static String removeNumberGroupingUsed(String value) {
		return (DataUtils.isNumberGrouping()) ? NumberUtils.removeNumberGrouping(value) : value;
	}

	/**
	 * Type 클래스의 유형이 숫자형인지 확인한다.
	 * 
	 * @param typeClass
	 * @return
	 */
	private static boolean isNumberTypeClass(Class typeClass) {
		if (typeClass == int.class || typeClass == Integer.class) {
			return true;
		} else if (typeClass == long.class || typeClass == Long.class) {
			return true;
		} else if (typeClass == float.class || typeClass == Float.class) {
			return true;
		} else if (typeClass == double.class || typeClass == Double.class) {
			return true;
		} else if (typeClass == java.math.BigDecimal.class) {
			return true;
		} else {
			return false;
		}
	}

}
