/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db;

import org.jdesigner.platform.context.ApplicationConfigUtils;
import org.jdesigner.platform.db.transaction.TransactionUtils;

/**
 * <B>Persistence Factory</B>
 * 
 * @author leesangboo
 * 
 */
public class PersistenceFactory {

	private static final String DATASOURCE_NAME_KEY = "platform.db.datasource.jndi";

	private static final String TRANSACTION_TYPE_KEY = "platform.db.transaction.type";

	/**
	 * 기본 퍼시스턴스를 생성한다.
	 * 
	 * @return
	 */
	public static Persistence createPersistence(String id) {
		String datasourceJNDIName = ApplicationConfigUtils.getProperty(DATASOURCE_NAME_KEY);
		String transactionType = ApplicationConfigUtils.getProperty(TRANSACTION_TYPE_KEY);
		return new PersistenceImpl(id, TransactionUtils.getTransactionType(transactionType), datasourceJNDIName);
	}

	/**
	 * 퍼시스턴스를 생성한다.
	 * 
	 * @param id
	 * @param dataSourceJNDIName
	 * @param transactionType
	 * @return
	 */
	public static Persistence createPersistence(String id, String dataSourceJNDIName, int transactionType) {
		return new PersistenceImpl(id, transactionType, dataSourceJNDIName);
	}

}
