/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db;

import java.sql.Connection;
import java.util.List;
import java.util.Map;

import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.Query;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.db.query.impl.NamedQueryImpl;
import org.jdesigner.platform.db.query.impl.QueryImpl;
import org.jdesigner.platform.db.query.impl.TableQueryImpl;
import org.jdesigner.platform.db.session.Session;
import org.jdesigner.platform.db.session.SessionManager;
import org.jdesigner.platform.db.transaction.Transaction;
import org.jdesigner.platform.db.transaction.TransactionManager;

/**
 * <B>Persistence Impl</B>
 * 
 * @author leesangboo
 * 
 */
public class PersistenceImpl extends PersistenceHelper implements Persistence {

	private String id;

	private SessionManager sessionManager = new SessionManager();

	private TransactionManager transactionManager = new TransactionManager();

	public PersistenceImpl(String id, int transactionType, String datasourceJNDIName) {
		//
		this.id = id;
		this.openSession(transactionType, datasourceJNDIName);
	}

	public void openSession(int transactionType, String datasourceJNDIName) {
		sessionManager.openSession(id, transactionType, datasourceJNDIName);
	}

	public Session getOpenedSession() {
		return sessionManager.getOpenedSession(id);
	}

	public void closeSession() {
		sessionManager.closeSession(id);
	}

	public Transaction getTransaction() {
		return getOpenedSession().getTransaction();
	}

	public void startTransaction() {
		transactionManager.start(getOpenedSession().getTransaction());
	}

	public void commitTransaction() {
		transactionManager.commit(getOpenedSession().getTransaction());
	}

	public void endTransaction() {
		transactionManager.end(getOpenedSession().getTransaction());
		getOpenedSession().removeTransaction();
	}

	public Connection getConnection() {
		return getOpenedSession().getConnection();
	}

	public void changeConnection(String dataSourceJNDIName) {
		getOpenedSession().changeConnection(dataSourceJNDIName);
	}

	public Query newQuery(String path) {
		return new QueryImpl(getOpenedSession(), path);
	}

	public Query newQuery(String path, List parameters) {
		return new QueryImpl(getOpenedSession(), path, parameters);
	}

	public NamedQuery newNamedQuery(String path) {
		return new NamedQueryImpl(getOpenedSession(), path);
	}

	public NamedQuery newNamedQuery(String path, Map parameters) {
		return new NamedQueryImpl(getOpenedSession(), path, parameters);
	}

	public TableQuery newTableQuery(String tableName) {
		return new TableQueryImpl(getOpenedSession(), tableName);
	}

	public TableQuery newTableQuery(String tableName, Map parameters) {
		return new TableQueryImpl(getOpenedSession(), tableName, parameters);
	}

	public TableQuery newTableQuery(String tableName, Map parameters, boolean onlyParamKeyBinding) {
		return new TableQueryImpl(getOpenedSession(), tableName, parameters, onlyParamKeyBinding);
	}

	public TableQuery newTableQuery(String tableName, Map parameters, String[] processTargetColumns) {
		return new TableQueryImpl(getOpenedSession(), tableName, processTargetColumns, parameters);
	}

	public TableQuery newTableQuery(String tableName, String[] primaryKeys, Map parameters) {
		return new TableQueryImpl(getOpenedSession(), tableName, primaryKeys, parameters);
	}

	public TableQuery newTableQuery(String tableName, String[] primaryKeys, Map parameters, boolean onlyParamKeyBinding) {
		return new TableQueryImpl(getOpenedSession(), tableName, primaryKeys, parameters, onlyParamKeyBinding);
	}

	public TableQuery newTableQuery(String tableName, String[] primaryKeys, Map parameters, String[] processTargetColumns) {
		return new TableQueryImpl(getOpenedSession(), tableName, primaryKeys, processTargetColumns, parameters);
	}

	public String getId() {
		return id;
	}

}
