/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.lob;

import java.sql.Blob;
import java.sql.Clob;
import java.sql.Connection;
import java.sql.SQLException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.db.onc.OracleNavtiveConnectionUtils;

/**
 * Oracle LOB 핸들러
 * 
 * @author leesangboo
 * 
 */
public class OracleLOBHandler implements LOBHandler {

	private static final Log log = LogFactory.getLog(OracleLOBHandler.class);

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.lob.LOBHandler#createClob(java.sql.Connection, java.lang.String)
	 */
	public Clob createClob(Connection conn, String value) throws SQLException {
		try {
			Clob tempClob = oracle.sql.CLOB.createTemporary(OracleNavtiveConnectionUtils.getNativeConnection(conn), false, oracle.sql.CLOB.DURATION_SESSION);
			((oracle.sql.CLOB) tempClob).setString(1, value.toString());
			return tempClob;
		} catch (Exception ex) {
			String msg = "OracleLOBHandler createClob error : " + ex.getMessage();
			log.error(msg, ex);
			throw new SQLException(ex.getMessage());
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.lob.LOBHandler#createBlob(java.sql.Connection, byte[])
	 */
	public Blob createBlob(Connection conn, byte[] value) throws SQLException {
		try {
			Blob tempBlob = oracle.sql.BLOB.createTemporary(OracleNavtiveConnectionUtils.getNativeConnection(conn), false, oracle.sql.BLOB.DURATION_SESSION);
			((oracle.sql.BLOB) tempBlob).setBytes(1, value);
			return tempBlob;
		} catch (Exception ex) {
			String msg = "OracleLOBHandler createBlob error : " + ex.getMessage();
			log.error(msg, ex);
			throw new SQLException(ex.getMessage());
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.lob.LOBHandler#readClob(java.sql.Clob)
	 */
	public String readClob(Clob clob) throws SQLException {
		try {
			String data = (clob != null ? clob.getSubString(1, (int) clob.length()) : null);
			return data;
		} catch (Exception ex) {
			String msg = "OracleLOBHandler readClob error : " + ex.getMessage();
			log.error(msg, ex);
			throw new SQLException(ex.getMessage());
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.lob.LOBHandler#readBlob(java.sql.Blob)
	 */
	public byte[] readBlob(Blob blob) throws SQLException {
		try {
			byte[] data = (blob != null ? blob.getBytes(1, (int) blob.length()) : null);
			return data;
		} catch (Exception ex) {
			String msg = "OracleLOBHandler readBlob error : " + ex.getMessage();
			log.error(msg, ex);
			throw new SQLException(ex.getMessage());
		}
	}

}
