/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.onc;

import java.sql.Connection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.db.connection.ConnectionException;

/**
 * <B>Navtive Oracle Connection Utils</B>
 * 
 * @author leesangboo
 * 
 */
public class OracleNavtiveConnectionUtils {

	private static final Log log = LogFactory.getLog(OracleNavtiveConnectionUtils.class);

	/**
	 * 웹 어플리케이션에서 제공하는 데이터 소스 커넥션으로부터 실제 오라클 커넥션 반환한다.
	 * 
	 * @return conn - 커넥션
	 * @throws Exception
	 */
	public static Connection getNativeConnection(Connection conn) throws ConnectionException {
		try {
			ApplicationContextFactory factory = ApplicationContextFactory.getInstance();
			String wasName = factory.getApplicationContext().getWasName();
			log.info("Native Oracle Connection : wasName=" + wasName + ", connClass=" + conn.getClass());
			if (conn instanceof oracle.jdbc.OracleConnection) {
				//
			} else {

				if (wasName.startsWith("Apache Tomcat")) { // 톰캣 커넥션
					CommonsDbcpNativeJdbcExtractor cdnje = new CommonsDbcpNativeJdbcExtractor();
					conn = cdnje.doGetNativeConnection(conn);
					return conn;
				}

				if (wasName.startsWith("WebLogic")) { // 웹로직 커넥션
					WebLogicOracleConnectionExtractor woce = new WebLogicOracleConnectionExtractor();
					conn = woce.doGetNativeConnection(conn);
					return conn;
				}

				if (wasName.startsWith("IBM WebSphere")) { // 웹스피어 커넥션
					WebSphereOracleConnectionExtractor wsoc = new WebSphereOracleConnectionExtractor();
					conn = wsoc.doGetNativeConnection(conn);
					return conn;
				}

				if (conn instanceof oracle.jdbc.OracleConnection) {

				} else {
					throw new ConnectionException("This connection not oracle vendor connection : oracle.jdbc.OracleConnection : " + conn);
				}
			}
			return conn;
		} catch (Exception ex) {
			throw new ConnectionException("Getting Oracle Native Connection Failed : " + ex.getMessage(), ex);
		}
	}

}
