/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.onc;

import java.lang.reflect.Method;
import java.sql.Connection;
import java.sql.SQLException;

import org.jdesigner.platform.util.ReflectionUtils;

/**
 * 웹로직 오라클 커넥션 엑스트랙터
 * 
 * @author SangBoo Lee
 * @since 2007-06-24
 */
public class WebLogicOracleConnectionExtractor {

	private static final String JDBC_EXTENSION_NAME = "weblogic.jdbc.extensions.WLConnection";

	private final Class jdbcExtensionClass;

	private final Method getVendorConnectionMethod;

	/**
	 * This constructor retrieves the WebLogic JDBC extension interface, so we can get the underlying vendor connection using reflection.
	 */
	public WebLogicOracleConnectionExtractor() {
		try {
			this.jdbcExtensionClass = getClass().getClassLoader().loadClass(JDBC_EXTENSION_NAME);
			this.getVendorConnectionMethod = this.jdbcExtensionClass.getMethod("getVendorConnection", (Class[]) null);
		} catch (Exception ex) {
			throw new IllegalStateException("Could not initialize WebLogicNativeJdbcExtractor because WebLogic API classes are not available: " + ex);
		}
	}

	/**
	 * Retrieve the Connection via WebLogic's <code>getVendorConnection</code> method.
	 */
	public Connection doGetNativeConnection(Connection con) throws SQLException {
		if (this.jdbcExtensionClass.isAssignableFrom(con.getClass())) {
			return (Connection) ReflectionUtils.invokeMethod(this.getVendorConnectionMethod, con);
		}
		return con;
	}

}
