/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.onc;

import java.lang.reflect.Method;
import java.sql.Connection;
import java.sql.SQLException;

import org.jdesigner.platform.util.ReflectionUtils;

/**
 * 웹스피어 오라클 커넥션 엑스트랙터
 * 
 * @author Administrator
 * @since 2007-06-24
 */
public class WebSphereOracleConnectionExtractor {

	private static final String JDBC_ADAPTER_CONNECTION_NAME_5 = "com.ibm.ws.rsadapter.jdbc.WSJdbcConnection";

	private static final String JDBC_ADAPTER_UTIL_NAME_5 = "com.ibm.ws.rsadapter.jdbc.WSJdbcUtil";

	private static final String CONNECTION_PROXY_NAME_4 = "com.ibm.ejs.cm.proxy.ConnectionProxy";

	private Class webSphere5ConnectionClass;

	private Class webSphere4ConnectionClass;

	private Method webSphere5NativeConnectionMethod;

	private Method webSphere4PhysicalConnectionMethod;

	/**
	 * This constructor retrieves WebSphere JDBC adapter classes, so we can get the underlying vendor connection using reflection.
	 */
	public WebSphereOracleConnectionExtractor() {
		// Detect WebSphere 5 connection classes.
		try {
			// logger.debug("Trying WebSphere 5 Connection: " +
			// JDBC_ADAPTER_CONNECTION_NAME_5);
			this.webSphere5ConnectionClass = getClass().getClassLoader().loadClass(JDBC_ADAPTER_CONNECTION_NAME_5);
			Class jdbcAdapterUtilClass = getClass().getClassLoader().loadClass(JDBC_ADAPTER_UTIL_NAME_5);
			this.webSphere5NativeConnectionMethod = jdbcAdapterUtilClass.getMethod("getNativeConnection", new Class[] { this.webSphere5ConnectionClass });
		} catch (Exception ex) {
			// logger.debug("Could not find WebSphere 5 connection pool classes");
		}

		// Detect WebSphere 4 connection classes.
		// Might also be found on WebSphere 5, for version 4 DataSources.
		try {
			// logger.debug("Trying WebSphere 4 Connection: " +
			// CONNECTION_PROXY_NAME_4);
			this.webSphere4ConnectionClass = getClass().getClassLoader().loadClass(CONNECTION_PROXY_NAME_4);
			this.webSphere4PhysicalConnectionMethod = this.webSphere4ConnectionClass.getMethod("getPhysicalConnection", (Class[]) null);
		} catch (Exception ex) {
			// logger.debug("Could not find WebSphere 4 connection pool classes");
		}
	}

	/**
	 * Retrieve the Connection via WebSphere's <code>getNativeConnection</code> method.
	 */
	public Connection doGetNativeConnection(Connection con) throws SQLException {
		// WebSphere 5 connection?
		if (this.webSphere5ConnectionClass != null && this.webSphere5ConnectionClass.isAssignableFrom(con.getClass())) {
			// WebSphere 5's WSJdbcUtil.getNativeConnection(wsJdbcConnection)
			return (Connection) ReflectionUtils.invokeMethod(this.webSphere5NativeConnectionMethod, null, new Object[] { con });
		}

		// WebSphere 4 connection (or version 4 connection on WebSphere 5)?
		else if (this.webSphere4ConnectionClass != null && this.webSphere4ConnectionClass.isAssignableFrom(con.getClass())) {
			// WebSphere 4's connectionProxy.getPhysicalConnection()
			return (Connection) ReflectionUtils.invokeMethod(this.webSphere4PhysicalConnectionMethod, con);
		}

		// No known WebSphere connection -> return as-is.
		else {
			// logger.debug("Connection [" + con +
			// "] is not a WebSphere 5/4 connection, returning as-is");
			return con;
		}
	}
}
