/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.paging;

import java.util.List;
import java.util.Map;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.parser.QueryParsingException;

/**
 * OraclePagingSQLHandler
 * 
 * @author leesangboo
 * 
 */
public class OraclePagingSQLHandler implements PagingSQLHandler {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.paging.PagingSQL#generatePagingSQL(java.lang .String)
	 */
	public String generatePagingSQL(String sql, String column, boolean desc) throws QueryParsingException {
		StringBuffer buffer = new StringBuffer();
		buffer.append("\n SELECT * ");
		buffer.append("\n FROM( ");
		buffer.append("\n SELECT " + PagingSQLHandler.PAGING_ALIAS + ".*, ROWNUM AS " + PagingSQLHandler.ROWNUM_ALIAS + " , COUNT(*) OVER () AS " + PagingSQLHandler.COUNT_ALIAS + " FROM ( ").append(
				"\n");
		buffer.append(sql.toString()); // /
		if (column != null && !column.equals("")) {
			buffer.append("\n ORDER BY " + column + " " + (desc ? "DESC" : "ASC") + " ");
		}
		buffer.append("\n ) " + PagingSQLHandler.PAGING_ALIAS + " ");
		buffer.append("\n ) ");
		buffer.append("\n WHERE " + PagingSQLHandler.ROWNUM_ALIAS + " > ? AND " + PagingSQLHandler.ROWNUM_ALIAS + " <= ? ");
		return buffer.toString();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.paging.PagingSQL#createParameter(java.lang .Object[], int, int)
	 */
	public Object[] createParameter(Object[] params, int start, int size) throws QueryParsingException {
		if (params != null) {
			Object[] newParams = new Object[params.length + 2];
			int maxIndex = 0;
			for (int i = 0; i < params.length; i++) {
				newParams[i] = params[i];
				maxIndex = i;
			}
			newParams[++maxIndex] = new Integer(start);
			newParams[++maxIndex] = new Integer(start + size);
			return newParams;
		} else {
			Object[] newParams = new Object[2];
			newParams[0] = new Integer(start);
			newParams[1] = new Integer(start + size);
			return newParams;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.paging.PagingSQL#generatePagingSQL(java.lang .String)
	 */
	public String generatePagingNamedSQL(String sql, String column, boolean desc) throws QueryParsingException {
		StringBuffer buffer = new StringBuffer();
		buffer.append("\n SELECT * ");
		buffer.append("\n FROM( ");
		buffer.append("\n SELECT " + PagingSQLHandler.PAGING_ALIAS + ".*, ROWNUM AS " + PagingSQLHandler.ROWNUM_ALIAS + " , COUNT(*) OVER () AS " + PagingSQLHandler.COUNT_ALIAS + " FROM ( ").append(
				"\n");
		buffer.append(sql.toString()); // /
		if (column != null && !column.equals("")) {
			buffer.append("\n ORDER BY " + column + " " + (desc ? "DESC" : "ASC") + " ");
		}
		buffer.append("\n ) " + PagingSQLHandler.PAGING_ALIAS + " ");
		buffer.append("\n ) ");
		buffer.append("\n WHERE " + PagingSQLHandler.ROWNUM_ALIAS + " > :" + Page.PAGE_START_PARAM_KEY + " AND " + PagingSQLHandler.ROWNUM_ALIAS + " <= :" + Page.PAGE_END_PARAM_KEY + " ");
		return buffer.toString();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.paging.PagingSQL#createParameter(java.lang .Object[], int, int)
	 */
	public Map createNamedParameter(Map params, int start, int range) throws QueryParsingException {
		if (params != null) {
			params.put(Page.PAGE_START_PARAM_KEY, new Integer(start));
			params.put(Page.PAGE_END_PARAM_KEY, new Integer(start + range));
			return params;
		} else {
			params = new java.util.HashMap();
			params.put(Page.PAGE_START_PARAM_KEY, new Integer(start));
			params.put(Page.PAGE_END_PARAM_KEY, new Integer(start + range));
			return params;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.paging.PagingSQLHandler#getCount(java.util .List)
	 */
	public long getCountFromResult(List list) throws QueryParsingException {
		long count = 0;
		if (list != null && list.size() > 0) {
			Map firstRow = (Map) list.get(0);
			String cnt = firstRow.get((PagingSQLHandler.COUNT_ALIAS).toLowerCase()).toString();
			count = Long.parseLong(cnt);
		}
		return count;
	}

}
