/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.parser;

import org.dom4j.Document;
import org.dom4j.Node;

import org.jdesigner.platform.context.ApplicationConfigUtils;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.StringUtils;

/**
 * <B>SQL String Extractor</B>
 * 
 * @author leesangboo
 * 
 */
public class SQLStringExtractor {

	private static final String SQL_NODE = "//statement/sql";

	private static final String ANNOTATION_AUTOGEN_PATH_KEY = "platform.annotation.autogenrated.db.path";

	/**
	 * Path로 부터 SQL을 추출한다.
	 * 
	 * @param path
	 * @return
	 * @throws Exception
	 */
	public String extraction(String path) throws QueryParsingException {
		try {

			//
			path = getRealPath(path);

			//
			SQLXMLDocumentLoader loader = new SQLXMLDocumentLoader();
			Document document = loader.load(path);
			//
			Node sqlNode = document.selectSingleNode(SQL_NODE);
			if (sqlNode == null) {
				throw new QueryParsingException("Not found <sql> node in document : path=[" + path + "]");
			}
			String sql = sqlNode.getText();
			return sql;
		} catch (Exception ex) {
			throw new QueryParsingException("Failed SQL string extraction from SQL XML document  : " + ex.getMessage());
		}
	}

	/**
	 * Getting real path for annotation
	 * 
	 * @param path
	 * @return
	 */
	private String getRealPath(String path) {
		//
		if (path.startsWith("annotation:")) {
			String appPath = ApplicationContextFactory.getInstance().getApplicationContext().getAppPath();
			String autoGeneratedPath = ApplicationConfigUtils.getProperty(ANNOTATION_AUTOGEN_PATH_KEY);
			String realPath = StringUtils.cleanPath("file:" + appPath + "/" + autoGeneratedPath) + "/";
			path = path.replaceAll("annotation:", realPath) + ".xml";
		}
		return path;
	}

}
