/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.parser.template.provider;

import java.io.StringReader;
import java.io.StringWriter;
import java.util.Map;

import org.jdesigner.platform.db.parser.QueryParsingException;
import org.jdesigner.platform.db.parser.template.QueryTemplateProcessor;
import org.jdesigner.platform.db.query.NamedQuery;

import freemarker.template.Configuration;
import freemarker.template.ObjectWrapper;
import freemarker.template.Template;
import freemarker.template.TemplateExceptionHandler;

/**
 * QueryTemplateFreemakerProcessor
 * 
 * @author leesangboo
 * 
 */
public class FreemakerSQLTemplateProvider implements QueryTemplateProcessor {

	/**
	 * 쿼리 템플릿을 파싱한다.
	 * 
	 * @param sql
	 * @param dataModel
	 * @return
	 * @throws Exception
	 */
	public String process(String sql, Map dataModel, Object query) throws Exception {
		String path = ((NamedQuery) query).getPath();
		return parseFreemarkerTemplate(sql, path, dataModel);
	}

	/**
	 * 프리메이커 기반의 템플릿을 파싱한다.
	 * 
	 * @param datamodel
	 * @param sql
	 * @return
	 * @throws Exception
	 */
	private String parseFreemarkerTemplate(String sql, String path, Object dataModel) throws Exception {
		try {

			// Using String
			Configuration configuration = new Configuration();
			configuration.setTemplateUpdateDelay(0);
			configuration.setTemplateExceptionHandler(TemplateExceptionHandler.DEBUG_HANDLER);
			configuration.setObjectWrapper(ObjectWrapper.BEANS_WRAPPER);
			configuration.setDefaultEncoding("UTF-8");
			//
			String uniqueTemplateName = path;
			//
			Template template = new Template(uniqueTemplateName, new StringReader(sql), configuration);
			StringWriter output = new StringWriter();
			template.process(dataModel, output);
			//
			return output.toString();

		} catch (Exception ex) {
			throw new QueryParsingException("Freemarker SQL template parsing error : " + ex.getMessage(), ex);
		}
	}

}
