/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.processor;

import java.util.List;
import java.util.Map;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.domain.UpdateResult;

/**
 * <B>Query Processor</B>
 * 
 * <PRE>
 * 
 * Apache Commons DBUtils를 확장한 SQL 쿼리 처리기입니다. 이 SQL 쿼리 처리기는 페이징된 조회 및 기본 SELECT, INSERT, UPDATE, DELETE, 반환되는 데이터 유형에 따라 다양한 API를 제공합니다.
 * 
 * </PRE>
 * 
 * @author leesangboo
 * 
 */
public interface QueryProcessor {

	/**
	 * 페이징 처리된 목록을 반환한다.
	 * 
	 * @param start
	 * @param range
	 * @param column
	 * @param desc
	 * @return
	 * @throws QueryProcessingException
	 */
	public abstract Page selectPage(int start, int range, String column, boolean desc) throws QueryProcessingException;

	/**
	 * [SELECT] SQL을 실행하여 List를 반환한다.
	 * 
	 * @param query
	 * 
	 * @return
	 * @throws QueryProcessingException
	 */
	public abstract List selectList() throws QueryProcessingException;

	/**
	 * [SELECT] SQL을 실행하여 Map<String, Object>를 반환한다.
	 * 
	 * @param query
	 * 
	 * @return
	 * @throws QueryProcessingException
	 */
	public abstract Map selectMap() throws QueryProcessingException;

	/**
	 * [SELECT] SQL을 실행하여 Object를 반환한다.
	 * 
	 * @param query
	 * 
	 * @return
	 * @throws QueryProcessingException
	 */
	public abstract Object selectObject() throws QueryProcessingException;

	/**
	 * [INSERT, UPDATE, DELETE] SQL을 실행하여 처리된 행의 갯수를 반환한다.
	 * 
	 * @param query
	 * 
	 * @return
	 * @throws QueryProcessingException
	 */
	public UpdateResult update() throws QueryProcessingException;

}