/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.processor;

import java.util.List;
import java.util.Map;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.domain.UpdateResult;

/**
 * <B>Table Query Processor</B>
 * 
 * @author leesangboo
 * 
 */
public interface TableQueryProcessor {

	public static final String SELECT_ALL = "SELECT_ALL";
	public static final String COUNT_ALL = "COUNT_ALL";
	public static final String SELECT_BY_PRIMARY_KEY = "SELECT_BY_PRIMARY_KEY";
	public static final String COUNT_BY_PRIMARY_KEY = "COUNT_BY_PRIMARY_KEY";
	public static final String SELECT_BY_CUSTOM_KEY = "SELECT_BY_CUSTOM_KEY";
	public static final String COUNT_BY_CUSTOM_KEY = "COUNT_BY_CUSTOM_KEY";
	public static final String INSERT = "INSERT";
	public static final String UPDATE = "UPDATE";
	public static final String DELETE = "DELETE";

	/**
	 * Find all table data rows.
	 * 
	 * @return
	 * @throws QueryProcessingException
	 */
	public abstract List selectAll() throws QueryProcessingException;

	public abstract long countAll() throws QueryProcessingException;

	public abstract Page selectAllPage(int start, int range, String column, boolean desc) throws QueryProcessingException;

	public abstract Map selectByPrimaryKey() throws QueryProcessingException;

	public abstract long countByPrimaryKey() throws QueryProcessingException;

	public abstract List selectByCustomKey() throws QueryProcessingException;

	public abstract long countByCustomKey() throws QueryProcessingException;

	public abstract UpdateResult insert() throws QueryProcessingException;

	public abstract UpdateResult update() throws QueryProcessingException;

	public abstract UpdateResult delete() throws QueryProcessingException;

}
