/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.processor.impl;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.domain.UpdateResult;
import org.jdesigner.platform.db.processor.QueryProcessingException;
import org.jdesigner.platform.db.processor.QueryProcessor;
import org.jdesigner.platform.db.processor.QueryValidateException;
import org.jdesigner.platform.db.query.Query;

/**
 * QueryProcessorImpl
 * 
 * @author leesangboo
 * 
 */
public class QueryProcessorImpl extends SQLProcessor implements QueryProcessor {

	private static final Log log = LogFactory.getLog(QueryProcessorImpl.class);

	private Query query;

	/**
	 * QueryProcessorImpl
	 * 
	 * @param query
	 */
	public QueryProcessorImpl(Query query) {
		this.query = query;
		this.validate();
		log.info("Query : " + query.toString());
	}

	/**
	 * 필수 값 검증
	 * 
	 */
	private void validate() {
		if (query.getPath() == null && query.getPath().equals("")) {
			throw new QueryValidateException("Query [path] value is null, this is required value.");
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.QueryProcessor#selectPage(org.architecture .common.db.Query, java.lang.Object[])
	 */
	public Page selectPage(int start, int range, String column, boolean desc) throws QueryProcessingException {
		try {
			return selectPage(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListParameters(query), start, range,
					column, desc);
		} catch (Exception ex) {
			String msg = "[findAll] processing failed : " + ex.getMessage();
			log.error(msg, ex);
			throw new QueryProcessingException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.QueryProcessor#selectList(org.architecture .common.db.Query, java.lang.Object[])
	 */
	public List selectList() throws QueryProcessingException {
		try {
			return selectList(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListParameters(query));
		} catch (Exception ex) {
			String msg = "[selectList] processing failed : " + ex.getMessage();
			log.error(msg, ex);
			throw new QueryProcessingException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.QueryProcessor#selectMap(org.architecture. common.db.Query, java.lang.Object[])
	 */
	public Map selectMap() throws QueryProcessingException {
		try {
			return selectMap(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListParameters(query));
		} catch (Exception ex) {
			String msg = "[selectMap] processing failed : " + ex.getMessage();
			log.error(msg, ex);
			throw new QueryProcessingException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.IQueryProcessor#selectObject(org.architecture .common.db.Query, java.lang.Object[])
	 */
	public Object selectObject() throws QueryProcessingException {
		try {
			return selectObject(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListParameters(query));
		} catch (Exception ex) {
			String msg = "[selectObject] processing failed : " + ex.getMessage();
			log.error(msg, ex);
			throw new QueryProcessingException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.IQueryProcessor#update(org.jdesigner.platform .db.Query, java.lang.Object[])
	 */
	public UpdateResult update() throws QueryProcessingException {
		try {
			return update(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListParameters(query));
		} catch (Exception ex) {
			String msg = "[update] processing failed : " + ex.getMessage();
			log.error(msg, ex);
			throw new QueryProcessingException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.IQueryProcessor#batch(org.jdesigner.platform .db.Query, java.lang.Object[][])
	 */
	public int[] batch() throws QueryProcessingException {
		return batch(query.getSession().getConnection(), query.getSession().getTransaction().isActive(), super.getParsedDynamicSQL(query), super.createListBatchParameters(query));
	}

}
