/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.transaction;

import javax.transaction.SystemException;
import javax.transaction.UserTransaction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.context.ApplicationConfigUtils;
import org.jdesigner.platform.db.connection.ConnectionUtils;
import org.jdesigner.platform.transaction.JTATransactionManager;

/**
 * <B>XA Transaction</B>
 * 
 * @author leesangboo
 * 
 */
public class JTATransaction extends BaseTransaction implements Transaction {

	protected static Log log = LogFactory.getLog(JTATransaction.class);

	private static final String JTA_JNDI_NAME_KEY = "platform.db.transaction.jta.jndi";

	private JTATransactionManager jtaTransactionManager = new JTATransactionManager();

	private UserTransaction userTransaction;

	/**
	 * LocalTransaction
	 * 
	 * @param connection
	 */
	public JTATransaction(String dataSourceJNDIName) {
		this.dataSourceJNDIName = dataSourceJNDIName;
		this.active = false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.Transaction#start()
	 */
	public void start() throws TransactionException {
		try {
			//
			if (userTransaction == null || !active) {
				userTransaction = null;
				String jndiName = ApplicationConfigUtils.getProperty(JTA_JNDI_NAME_KEY);
				userTransaction = jtaTransactionManager.begin(jndiName);
				log.info("New user transaction created : id=" + userTransaction);
			}
			active = true;

		} catch (Exception ex) {
			String msg = "Cannot start a JTA transaction : " + ex.getMessage();
			log.error(msg, ex);
			throw new TransactionException(msg, ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.Transaction#commit()
	 */
	public void commit() {
		try {
			jtaTransactionManager.commit(userTransaction);
			active = false;
			commited = true;
		} finally {
			super.closeChangedConnections();
			ConnectionUtils.closeConnection(connection);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.Transaction#rollback()
	 */
	public void rollback() {
		try {
			jtaTransactionManager.rollback(userTransaction);
			active = false;
		} finally {
			super.closeChangedConnections();
			ConnectionUtils.closeConnection(connection);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.transaction.Transaction#setTimeout(int)
	 */
	public void setTimeout(int time) {
		try {
			userTransaction.setTransactionTimeout(time);
		} catch (SystemException e) {
			e.printStackTrace();
		}
	}

}
