/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.transaction;

import java.sql.Connection;
import java.util.Map;

/**
 * <B>Transaction</B>
 * 
 * @author leesangboo
 * 
 */
public interface Transaction {

	public static final int JDBC = 1;
	public static final int JTA = 2;
	public static final int NONE = 3;

	/**
	 * 커넥션을 반환한다.
	 * 
	 * @return
	 */
	public Connection getConnection() throws TransactionException;

	/**
	 * 변경된 커넥션을 반환한다.
	 */
	public Map getChangedConnectionMap() throws TransactionException;

	/**
	 * 커넥션을 변경한다.
	 * 
	 * @param datasourceJNDIName
	 */
	public void changeConnection(String dataSourceJNDIName) throws TransactionException;

	/**
	 * 트랜잭션의 활성 여부를 반환한다.
	 * 
	 * @return
	 */
	public boolean isActive();

	/**
	 * 트랜잭션의 활성 커밋를 반환한다.
	 * 
	 * @return
	 */
	public boolean isCommited();

	/**
	 * 트랜잭션을 시작한다.
	 * 
	 * @throws TransactionException
	 */
	public abstract void start() throws TransactionException;

	/**
	 * 트랜잭션을 완료한다.
	 * 
	 */
	public abstract void commit();

	/**
	 * 트랜잭션을 롤백한다.
	 * 
	 */
	public abstract void rollback();

	/**
	 * 트랜잭션 타임아웃을 설정한다.
	 * 
	 * @param time
	 */
	public abstract void setTimeout(int time);

}