/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.scheduler.task;

import java.util.HashMap;
import java.util.Map;

/**
 * Contains information related to a single task to be executed by the <code>SchedulerServlet</code>.
 * 
 * @author Pascal Essiembre
 * @version $Id: SchedulerTaskInfo.java,v 1.3 2004/06/07 03:46:40 essiembre Exp $
 */
public class SchedulerTaskInfo {

	/** Job Name */
	private String name = null;

	/** Qualified name of TimerTask class to be executed */
	private String task = null;

	/** When should the task be executed */
	private String time = null;

	/** Time in milliseconds between successive task executions */
	private String period = null;

	/** Delay in milliseconds before task is to be executed */
	private String delay = null;

	/** Scheduler parameters */
	private Map parameters = new HashMap();

	/**
	 * Gets the delay
	 * 
	 * @return Returns a String representation of a delay
	 */
	public String getDelay() {

		return delay;
	}

	/**
	 * Sets the delay
	 * 
	 * @param delay
	 *            The delay to set
	 */
	public void setDelay(String delay) {
		this.delay = delay;
	}

	/**
	 * Gets the period
	 * 
	 * @return Returns a String representation of a period
	 */
	public String getPeriod() {

		return period;
	}

	/**
	 * Sets the period
	 * 
	 * @param period
	 *            The period to set
	 */
	public void setPeriod(String period) {
		this.period = period;
	}

	/**
	 * Gets the task
	 * 
	 * @return Returns a String
	 */
	public String getTask() {

		return task;
	}

	/**
	 * Sets the task
	 * 
	 * @param task
	 *            The task to set
	 */
	public void setTask(String task) {
		this.task = task;
	}

	/**
	 * Gets the time
	 * 
	 * @return Returns a String representation of a date
	 */
	public String getTime() {

		return time;
	}

	/**
	 * Sets the time. The provided String will be converted to a <code>Date</code> when used to create a new <code>Timer</code>. It must conform to
	 * this format: yyyy-MM-dd HH:mm:ss (see <code>java.text.SimpleDateFormat</code>).
	 * 
	 * @param time
	 *            The time to set
	 */
	public void setTime(String time) {

		this.time = time;
	}

	/**
	 * Gets the parameters.
	 * 
	 * @return Returns the parameters.
	 * @since 1.1
	 */
	public Map getParameters() {
		return parameters;
	}

	/**
	 * Sets the parameters.
	 * 
	 * @param parameters
	 *            The parameters to set.
	 * @since 1.1
	 */
	public void setParameters(Map parameters) {
		this.parameters = parameters;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

}