/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionMapping;
import org.apache.struts.validator.ValidatorForm;

/**
 * All actions mapped through the BeanAction class should be mapped <p/> to a subclass of BaseBean (or have no form bean mapping at all). <p/> <p/>
 * <p/> The BaseBean class simplifies the validate() and reset() methods <p/> by allowing them to be managed without Struts dependencies. Quite <p/>
 * simply, subclasses can override the parameterless validate() <p/> and reset() methods and set errors and messages using the ActionContext <p/>
 * class. <p/> <p/> <p/> <i>Note: Full error, message and internationalization support is not complete.</i> <p/> <p/> <p/> Date: Mar 12, 2004 9:20:39
 * PM
 * 
 * @author Clinton Begin
 */
public abstract class BaseBean extends ValidatorForm {

	private static final long serialVersionUID = 4444124549060734634L;

	private ActionInterceptor interceptor;

	protected BaseBean() {
		this.interceptor = new DefaultActionInterceptor();
	}

	protected BaseBean(ActionInterceptor interceptor) {
		this.interceptor = interceptor;
	}

	public final void reset(ActionMapping mapping, ServletRequest request) {
		ActionBeanContext.initCurrentContext((HttpServletRequest) request, null);
		reset();
	}

	public final void reset(ActionMapping mapping, HttpServletRequest request) {
		ActionBeanContext.initCurrentContext(request, null);
		reset();
	}

	public void reset() {
		//
	}

	public ActionInterceptor getInterceptor() {
		return interceptor;
	}

}
