/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMessage;

/**
 * BaseForm
 * 
 * @author leesangboo
 * 
 */
public abstract class BaseForm extends ActionForm {

	private static final long serialVersionUID = -2476255968147580345L;

	private static Logger log = Logger.getLogger(BaseForm.class);

	private static final SimpleDateFormat DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss");

	protected Locale locale;

	public BaseForm() {
		this.locale = Locale.getDefault();
	}

	protected String formatDate(long date) {
		return DATE_FORMAT.format(new Date(date));
	}

	protected URL parseURL(String s) {
		if (s == null) {
			return null;
		}
		try {
			URL url = new URL(s);
			return url;
		} catch (Exception e) {
		}
		return null;
	}

	protected String toStringURL(URL url) {
		if (url == null) {
			return "";
		}
		try {
			return url.toExternalForm();
		} catch (Exception e) {
			log.error(e);
			return "exception : " + e;
		}
	}

	protected void checkForEmpty(String fieldName, String fieldKey, int value, ActionErrors errors) {
		String sValue = "" + value;
		checkForEmpty(fieldName, fieldKey, sValue, errors);
	}

	protected void checkForEmpty(String fieldName, String fieldKey, String value, ActionErrors errors) {
		if ((value == null) || (value.trim().length() == 0)) {
			ActionMessage error = new ActionMessage(fieldKey, fieldName);
			errors.add(fieldKey, error);
		}
	}

	protected void checkForLength(String fieldName, String fieldKey, String value, int maxLength, ActionErrors errors) {
		if (value.trim().length() > maxLength) {
			ActionMessage error = new ActionMessage(fieldKey, fieldName);
			errors.add(fieldKey, error);
		}
	}

}