/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.InvalidCancelException;
import org.apache.struts.tiles.TilesRequestProcessor;
import org.apache.struts.util.MessageResources;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.core.threadlocal.ThreadLocalProperties;
import org.jdesigner.platform.web.validator.Validator;

/**
 * <B>Base Tiles Request Processor</B>
 * 
 * @author leesangboo
 * 
 */
public class BaseTilesRequestProcessor extends TilesRequestProcessor {

	private static final Log log = LogFactory.getLog(BaseRequestProcessor.class);

	private static final String PARAMETER_ENCODING_KEY = "platform.web.parameter.encoding";

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts.action.RequestProcessor#processPreprocess(javax.servlet .http.HttpServletRequest,
	 * javax.servlet.http.HttpServletResponse)
	 */
	protected boolean processPreprocess(HttpServletRequest request, HttpServletResponse response) {
		try {
			ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
			String paramEncoding = appFactory.getApplicationContext().getApplicationConfig().getProperty(PARAMETER_ENCODING_KEY);
			if (!request.getCharacterEncoding().equals(paramEncoding)) {
				request.setCharacterEncoding(paramEncoding);
			}
		} catch (Exception ex) {
			log.error("Parameter encoding setting error : " + ex.getMessage());
			ex.printStackTrace();
		}
		;
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts.action.RequestProcessor#processValidate(javax.servlet .http.HttpServletRequest, javax.servlet.http.HttpServletResponse,
	 * org.apache.struts.action.ActionForm, org.apache.struts.action.ActionMapping)
	 */
	protected boolean processValidate(HttpServletRequest request, HttpServletResponse response, ActionForm form, ActionMapping mapping) throws IOException, ServletException, InvalidCancelException {
		org.jdesigner.platform.web.ActionMapping aMapping = (org.jdesigner.platform.web.ActionMapping) mapping;
		String validatorClass = aMapping.getValidator();

		Validator validator = null;

		if (!org.apache.commons.lang.StringUtils.isBlank(validatorClass)) {
			try {
				validator = (Validator) Class.forName(validatorClass).newInstance();
			} catch (InstantiationException e1) {
				e1.printStackTrace();
			} catch (IllegalAccessException e1) {
				e1.printStackTrace();
			} catch (ClassNotFoundException e1) {
				e1.printStackTrace();
			}

			log.debug("Custom validator : " + validatorClass);

			MessageResources messageResources = ((MessageResources) request.getAttribute(Globals.MESSAGES_KEY));
			ActionErrors errors = validator.validate(new ActionInput(request), messageResources);
			if (errors != null) {
				log.debug("Validate failed, setting error messages.");
				request.setAttribute(WebConstants.VALIDATION_ERROR_KEY, errors);
			}
			return true;
		} else {
			return super.processValidate(request, response, form, mapping);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts.action.RequestProcessor#processLocale(javax.servlet .http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	protected void processLocale(HttpServletRequest request, HttpServletResponse response) {
		//
		//if (!moduleConfig.getControllerConfig().getLocale()) {
		//	return;
		//}
		//
		HttpSession session = request.getSession();
		if (session.getAttribute(Globals.LOCALE_KEY) != null) {
			ThreadLocalProperties.put(Globals.LOCALE_KEY, session.getAttribute(Globals.LOCALE_KEY));
			if (request.getAttribute(Globals.MESSAGE_KEY) != null) {
				ThreadLocalProperties.put(Globals.MESSAGE_KEY, request.getAttribute(Globals.MESSAGE_KEY));
			}
			return;
		}
		;
	}

}