/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.apache.struts.action.ActionForward;

public class ForwardParameters {

	private Map params = null;

	public ForwardParameters() {
		params = new HashMap();
	}

	public ForwardParameters(Map map) {
		params = map;
	}

	/**
	 * Add a single parameter and value.
	 * 
	 * @param paramName
	 *            Parameter name
	 * @param paramValue
	 *            Parameter value
	 * 
	 * @return A reference to this object.
	 */
	public ForwardParameters add(String paramName, String paramValue) {
		params.put(paramName, paramValue);
		return this;
	}

	/**
	 * Add a set of parameters and values.
	 * 
	 * @param paramMap
	 *            Map containing parameter names and values.
	 * 
	 * @return A reference to this object.
	 */
	public ForwardParameters add(Map paramMap) {
		Iterator itr = paramMap.keySet().iterator();
		while (itr.hasNext()) {
			String paramName = (String) itr.next();
			params.put(paramName, paramMap.get(paramName));
		}

		return this;
	}

	/**
	 * Add parameters to a provided ActionForward.
	 * 
	 * @param forward
	 *            The ActionForward object to add parameters to.
	 * 
	 * @return ActionForward with parameters added to the URL.
	 */
	public ActionForward forward(ActionForward forward) {
		StringBuffer path = new StringBuffer(forward.getPath());

		Iterator itr = params.entrySet().iterator();
		if (itr.hasNext()) {
			// add first parameter, if avaliable
			Map.Entry entry = (Map.Entry) itr.next();
			path.append("?" + entry.getKey() + "=" + entry.getValue());

			// add other parameters
			while (itr.hasNext()) {
				entry = (Map.Entry) itr.next();
				path.append("&" + entry.getKey() + "=" + entry.getValue());
			}
		}

		return new ActionForward(path.toString());
	}
}