/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts.Globals;
import org.apache.struts.config.ModuleConfig;
import org.apache.struts.util.LabelValueBean;
import org.apache.struts.util.MessageResources;
import org.apache.struts.util.ModuleUtils;

import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.locale.LocaleHandler;
import org.jdesigner.platform.web.locale.LocaleHandlerFactory;
import org.jdesigner.platform.web.theme.ThemeHandler;

/**
 * <B>Web Utils</B>
 * 
 * @author leesangboo
 * 
 */
public class WebUtils {

	/**
	 * Tag Lib으로 표시할 처음 선택에 (선택)이 추가된 LabelValueBean List를 생성한다.
	 * 
	 * @param list
	 * @param labelKey
	 * @param valueKey
	 * @return
	 */
	public static List createOptionsAppendChoice(HttpServletRequest request, List list, String labelKey, String valueKey) {
		String msg = getResources(request).getMessage("common.html.select.choice");
		return createOptions(list, labelKey, valueKey, msg, "");
	}

	/**
	 * Tag Lib으로 표시할 처음 선택에 (ALL)이 추가된 LabelValueBean List를 생성한다.
	 * 
	 * @param list
	 * @param labelKey
	 * @param valueKey
	 * @return
	 */
	public static List createOptionsAppendAll(HttpServletRequest request, List list, String labelKey, String valueKey) {
		String msg = getResources(request).getMessage("common.html.select.all");
		return createOptions(list, labelKey, valueKey, msg, "");
	}

	/**
	 * Tag Lib으로 표시할 처음 선택에 (빈 공백)이 추가된 LabelValueBean List를 생성한다.
	 * 
	 * @param list
	 * @param labelKey
	 * @param valueKey
	 * @return
	 */
	public static List createOptionsAppendBlank(List list, String labelKey, String valueKey) {
		return createOptions(list, labelKey, valueKey, "", "");
	}

	/**
	 * Tag Lib으로 표시할 LabelValueBean List를 생성한다.
	 * 
	 * @param list
	 * @param labelKey
	 * @param valueKey
	 * @return
	 */
	public static List createOptions(List list, String labelKey, String valueKey) {
		return createOptions(list, labelKey, valueKey, null, null);
	}

	/**
	 * Tag Lib으로 표시할 LabelValueBean List를 생성한다.
	 * 
	 * @param list
	 * @param labelKey
	 * @param valueKey
	 * @param firstLabelKey
	 * @param firstValueKey
	 * @return
	 */
	public static List createOptions(List list, String labelKey, String valueKey, String firstLabelKey, String firstValueKey) {
		List options = new ArrayList();
		if (StringUtils.isNotEmpty(firstLabelKey)) {
			options.add(new LabelValueBean(firstLabelKey, firstValueKey));
		}
		if (list != null && list.size() > 0) {
			for (int i = 0; i < list.size(); i++) {
				Map map = (Map) list.get(i);
				if (!map.containsKey(labelKey)) {
					throw new RuntimeException("createOptions error : [labelKey] containsKey false.");
				}
				if (!map.containsKey(valueKey)) {
					throw new RuntimeException("createOptions error : [valueKey] containsKey false.");
				}
				options.add(new LabelValueBean(map.get(labelKey).toString(), map.get(valueKey).toString()));
			}
		} else {
			// options = null;
		}
		return options;
	}

	/**
	 * 기본 메세지 리소스를 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public static MessageResources getResources(HttpServletRequest request) {
		return ((MessageResources) request.getAttribute(Globals.MESSAGES_KEY));
	}

	/**
	 * 키에 해당하는 메세지 리소스를 반환한다.
	 * 
	 * @param request
	 * @param key
	 * @return
	 */
	public static MessageResources getResources(HttpServletRequest request, String key) {
		ServletContext context = request.getSession().getServletContext();
		ModuleConfig moduleConfig = ModuleUtils.getInstance().getModuleConfig(request, context);
		return (MessageResources) context.getAttribute(key + moduleConfig.getPrefix());
	}

	/**
	 * ContextPath를 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public static String getContextPath(HttpServletRequest request) {
		return request.getContextPath();
	}

	/**
	 * 지역 핸들러를 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public static LocaleHandler getLocaleHandler() {
		LocaleHandlerFactory factory = LocaleHandlerFactory.getInstance();
		return factory.getLocaleHandler();
	}

	/**
	 * 테마명을 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public static ThemeHandler getThemeHandler() {
		return new ThemeHandler();
	}

	/**
	 * 문자를 로케일로 변경한다.
	 * 
	 * @param str
	 * @return
	 */
	public static Locale stringToLocale(String str) {
		Locale locale = null;
		if (str.indexOf("_") > -1) {
			locale = new Locale(str.substring(0, str.indexOf("_")), str.substring(str.indexOf("_") + 1));
		} else {
			locale = new Locale(str);
		}
		return locale;
	}

}
