/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.filter;

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Wraps Response for GZipFilter
 * 
 */
public class GZIPResponseWrapper extends HttpServletResponseWrapper {

	private final static Log log = LogFactory.getLog(GZIPResponseWrapper.class);

	protected HttpServletResponse origResponse = null;

	protected ServletOutputStream stream = null;

	protected PrintWriter writer = null;

	protected int error = 0;

	public GZIPResponseWrapper(HttpServletResponse response) {
		super(response);
		origResponse = response;
	}

	public ServletOutputStream createOutputStream() throws IOException {
		return (new GZIPResponseStream(origResponse));
	}

	public void finishResponse() {
		try {
			if (writer != null) {
				writer.close();
			} else {
				if (stream != null) {
					stream.close();
				}
			}
		} catch (IOException e) {
			log.info("finishResponse", e);
		}
	}

	public void flushBuffer() throws IOException {
		stream.flush();
	}

	public ServletOutputStream getOutputStream() throws IOException {
		if (writer != null) {
			throw new IllegalStateException("getWriter() has already been called!");
		}

		if (stream == null) {
			stream = createOutputStream();
		}

		return (stream);
	}

	public PrintWriter getWriter() throws IOException {
		// If access denied, don't create new stream or write because
		// it causes the web.xml's 403 page to not render
		if (this.error == HttpServletResponse.SC_FORBIDDEN) {
			return super.getWriter();
		}

		if (writer != null) {
			return (writer);
		}

		if (stream != null) {
			throw new IllegalStateException("getOutputStream() has already been called!");
		}

		stream = createOutputStream();
		writer = new PrintWriter(new OutputStreamWriter(stream, origResponse.getCharacterEncoding()));

		return (writer);
	}

	public void setContentLength(int length) {
		// no action here
	}

	/**
	 * @see javax.servlet.http.HttpServletResponse#sendError(int, java.lang.String)
	 */
	public void sendError(int err, String message) throws IOException {
		super.sendError(err, message);
		this.error = err;

		if (log.isDebugEnabled()) {
			log.debug("sending error: " + err + " [" + message + "]");
		}
	}
}