/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.grid;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jdesigner.platform.data.Page;

/**
 * <B>Grid</B>
 * 
 * @author leesangboo
 * 
 */
public class Grid extends Page {

	public static final String FORWARD = "grid";

	private Map columns;

	private Map decorators;

	/**
	 * Grid
	 * 
	 * @param start
	 * @param range
	 */
	public Grid() {
		super(0, 15);
	}

	/**
	 * Grid
	 * 
	 * @param page
	 */
	public Grid(Page page) {
		super(page.getCount(), page.getList(), page.getStart(), page.getRange(), page.getSort(), page.isDesc());
	}

	/**
	 * Grid
	 * 
	 * @param start
	 * @param range
	 */
	public Grid(int start, int range) {
		super(start, range);
	}

	/**
	 * Grid
	 * 
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 */
	public Grid(int start, int range, String sort, boolean desc) {
		super(start, range, sort, desc);
	}

	/**
	 * Grid
	 * 
	 * @param count
	 * @param list
	 * @param start
	 * @param range
	 */
	public Grid(long count, List list, int start, int range) {
		super(count, list, start, range);
	}

	/**
	 * Grid
	 * 
	 * @param count
	 * @param list
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 */
	public Grid(long count, List list, int start, int range, String sort, boolean desc) {
		super(count, list, start, range, sort, desc);
	}

	/**
	 * 
	 * @param key
	 * @param decorator
	 */
	public void addDecorator(String key, Decorator decorator) {
		if (decorators == null) {
			decorators = new HashMap();
		}
		decorators.put(key, decorator);
	}

	/**
	 * 
	 * @param key
	 */
	public void removeDecorator(String key) {
		if (decorators == null) {
			return;
		}
		decorators.remove(key);
	}

	/**
	 * 
	 * @param key
	 * @param decorator
	 */
	public void addColumn(String key, Column column) {
		if (columns == null) {
			columns = new HashMap();
		}
		columns.put(key, column);
	}

	/**
	 * 
	 * @param key
	 */
	public void removeColumn(String key) {
		if (decorators == null) {
			return;
		}
		decorators.remove(key);
	}

	/**
	 * 
	 * @return
	 */
	public Map getDecorators() {
		return decorators;
	}

	/**
	 * 
	 * @param decorators
	 */
	public void setDecorators(Map decorators) {
		this.decorators = decorators;
	}

	/**
	 * 
	 * @return
	 */
	public Map getColumns() {
		return columns;
	}

	/**
	 * 
	 * @param columns
	 */
	public void setColumns(Map columns) {
		this.columns = columns;
	}

	/**
	 * 
	 * @return
	 */
	public String toJSON() {
		return null;
	}

	/**
	 * 
	 * @return
	 */
	public String toXML() {
		return null;
	}

}
