/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.html;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jdesigner.platform.data.DataUtils;
import org.jdesigner.platform.web.WebUtils;
import org.jdesigner.platform.web.tag.JSPTagException;

/**
 * DateTag
 * 
 * @author leesangboo
 * 
 */
public class DateTag extends ExtendedBaseFieldTag {

	private static final long serialVersionUID = 1L;

	public DateTag() {
		super();
		this.type = "text";
		doReadonly = true;
	}

	private boolean selector = true;

	private String pattern = DataUtils.getDatePattern();

	public String getDataType() {
		return "date";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.html.ExtendedBaseFieldTag#getSupportScript ()
	 */
	public String getSupportScript() {
		StringBuffer sb = null;
		try {

			HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();
			HttpServletResponse response = (HttpServletResponse) pageContext.getResponse();
			String contextPath = request.getContextPath();

			// String message =
			// WebUtils.getResources(request).getMessage("key");
			String language = WebUtils.getLocaleHandler().getUserLocale(request, response).getLanguage();

			//
			sb = new StringBuffer();
			sb.append(SCRIPT_TAG_START);
			sb.append("   window.addEvent('domready', function(){ ");
			sb.append("   	 var _date_mask_" + property.replaceAll("\\.", "_") + " = new DateMask('" + pattern + "', '" + property + "'); ");
			sb.append("     });  ");
			sb.append(SCRIPT_TAG_END);

			if (selector) {
				String varObj = "_date_selector_" + this.getStyleId();
				sb.append(SCRIPT_TAG_START);
				sb.append(" var " + varObj + ";");
				sb.append("    window.addEvent('domready', function(){	");
				sb.append("        " + varObj + " = dateSelector.create(" + varObj + ", '" + this.getStyleId() + "', '" + language + "'); ");
				sb.append("    }); ");
				sb.append(SCRIPT_TAG_END);
				// sb.append("<span class='dateSelector'>");
				sb.append("<img src='" + contextPath + "/images/dateselector/dateselector.gif' onclick='" + varObj + ".show();' class='dateSelector' align='absmiddle'/>");
				// sb.append("</span>");
			}

			return sb.toString();
		} catch (Exception e) {
			throw new JSPTagException(e.getMessage(), e);
		}
	}

	public String getPattern() {
		return pattern;
	}

	public void setPattern(String pattern) {
		this.pattern = pattern;
	}

	public boolean isSelector() {
		return selector;
	}

	public void setSelector(boolean selector) {
		this.selector = selector;
	}

}
