/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.html;

import java.text.NumberFormat;

import javax.servlet.jsp.JspException;

import org.apache.struts.taglib.TagUtils;

import org.jdesigner.platform.data.DataUtils;
import org.jdesigner.platform.util.DateUtils;
import org.jdesigner.platform.web.tag.JSPTagException;
import org.jdesigner.platform.web.tag.TagConstants;

/**
 * ExtendedBaseFieldTag
 * 
 * @author leesangboo
 * 
 */
public abstract class ExtendedBaseFieldTag extends org.apache.struts.taglib.html.BaseFieldTag implements TagConstants {

	private static final long serialVersionUID = 1L;

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts.taglib.html.BaseFieldTag#renderInputElement()
	 */
	protected String renderInputElement() throws JspException {

		StringBuffer results = new StringBuffer("<input");

		prepareAttribute(results, "type", this.type);
		prepareAttribute(results, "name", prepareName());
		prepareAttribute(results, "accesskey", getAccesskey());
		prepareAttribute(results, "accept", getAccept());
		prepareAttribute(results, "maxlength", getMaxlength());
		prepareAttribute(results, "size", getCols());
		prepareAttribute(results, "tabindex", getTabindex());
		prepareValue(results);
		results.append(this.prepareEventHandlers());
		results.append(this.prepareStyles());
		if (!isXhtml()) {
			prepareAttribute(results, "autocomplete", getAutocomplete());
		}
		prepareOtherAttributes(results);

		prepareAttribute(results, "dataType", getDataType());

		// results.append(this.getElementClose());
		results.append(" />");

		// 지원 스크립트
		results.append(getSupportScript());

		return results.toString();
	}

	/**
	 * 추가 지원 스크립트
	 * 
	 * @return
	 */
	public abstract String getSupportScript();

	/**
	 * 데이터 타입을 반환한다.
	 * 
	 * @return
	 */
	public abstract String getDataType();

	/**
	 * HTML TAG Value formmat
	 */
	protected String formatValue(Object value) throws JspException {

		try {

			if (value == null) {
				return "";
			}

			String convertedValue = null;
			Class classType = value.getClass();

			// System.out.println("classType=" + classType);

			if (value instanceof Number) {
				NumberFormat format = NumberFormat.getInstance();
				format.setGroupingUsed(DataUtils.isNumberGrouping());
				convertedValue = format.format(value);
			}

			// java.util.Date
			if (classType.equals(java.util.Date.class)) {
				convertedValue = DateUtils.dateToString(DataUtils.getDatePattern(), (java.util.Date) value);
			}

			// java.sql.Date
			if (classType.equals(java.sql.Date.class)) {
				convertedValue = DateUtils.sqlDateToString(DataUtils.getDatePattern(), (java.sql.Date) value);
			}

			// java.sql.Time
			if (classType.equals(java.sql.Time.class)) {
				convertedValue = DateUtils.timeToString(DataUtils.getTimePattern(), (java.sql.Time) value);
			}

			// java.sql.Timestamp
			if (classType.equals(java.sql.Timestamp.class)) {
				convertedValue = DateUtils.timestampToString(DataUtils.getDateTimePattern(), (java.sql.Timestamp) value);
			}

			if (convertedValue == null) {
				convertedValue = value.toString();
			}

			return TagUtils.getInstance().filter(convertedValue);

		} catch (Exception e) {
			throw new JSPTagException("Filed tag format value error : " + e.getMessage(), e);
		}
	}

}
