/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyTagSupport;
import javax.servlet.jsp.tagext.Tag;

import org.jdesigner.platform.web.WebUtils;
import org.jdesigner.platform.web.theme.Theme;

/**
 * GridColumnTag
 * 
 * @author leesangboo
 * 
 */
public class GridColumnTag extends BodyTagSupport implements Tag, Serializable {

	private static final long serialVersionUID = 1L;

	protected Tag parent = null;

	//
	private String header;

	private String dataIndex;

	private String dataType;

	private String type;

	private String width;

	private String align;

	private String src;

	private String styleClass;

	private boolean sortable;

	private boolean hidden;

	//
	private String onClick;

	private String onDbClick;

	// for checkbox
	private String onChange;

	//
	private String labelFunction;

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.Tag#release()
	 */
	public void release() {
		//
		pageContext = null;
		parent = null;

		//
		header = "";
		dataIndex = "";
		dataType = "";
		type = "";
		width = "";
		align = "";
		styleClass = "";
		sortable = false;
		hidden = false;
		src = "";

		//
		onClick = "";
		onDbClick = "";
		onChange = "";
		labelFunction = "";
	}

	public int doStartTag() throws JspException {

		try {

			GridTag gridTag = (GridTag) this.getParent();
			String gridId = gridTag.getId();

			List columnModelList = (List) pageContext.getAttribute(TagConstants.GRID_COLUMN_MODEL_KEY + "_" + gridId);
			if (columnModelList == null) {
				columnModelList = new ArrayList();
			}

			Map column = new HashMap();
			column.put("header", header);
			column.put("dataIndex", dataIndex);
			column.put("dataType", dataType == null ? "" : dataType);
			column.put("type", type == null ? "" : type);
			column.put("width", width);
			column.put("align", align);
			column.put("styleClass", styleClass == null ? "" : styleClass);
			column.put("sortable", new Boolean(sortable));
			column.put("hidden", new Boolean(hidden));

			if (src != null) {
				if (src.startsWith("/")) {
					column.put("src", getRequest().getContextPath() + src);
				} else {
					column.put("src", src);
				}
			} else {
				column.put("src", "");
			}

			column.put("onClick", onClick == null ? "" : onClick);
			column.put("onDbClick", onDbClick == null ? "" : onDbClick);
			column.put("onChange", onChange == null ? "" : onChange);
			column.put("labelFunction", labelFunction == null ? "" : labelFunction);

			columnModelList.add(column);

			pageContext.setAttribute(TagConstants.GRID_COLUMN_MODEL_KEY + "_" + gridId, columnModelList);

		} catch (Exception e) {
			throw new UITagException("Grid Column Tag Error : " + e.getMessage(), e);
		}
		return SKIP_BODY;
	}

	public void setParent(Tag t) {
		parent = t;
	}

	public Tag getParent() {
		return parent;
	}

	/**
	 * HttpServletRequest을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletRequest getRequest() {
		return ((HttpServletRequest) pageContext.getRequest());
	}

	/***
	 * HttpServletResponse을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletResponse getResponse() {
		return ((HttpServletResponse) pageContext.getResponse());
	}

	/**
	 * Context Path를 반환한다.
	 * 
	 * @return
	 */
	public String getContextPath() {
		return getRequest().getContextPath();
	}

	/**
	 * 사용자의 테마를 반환한다.
	 * 
	 * @return
	 */
	public Theme getUserTheme() {
		return WebUtils.getThemeHandler().getUserTheme(getRequest());
	}

	public String getAlign() {
		return align;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public String getDataIndex() {
		return dataIndex;
	}

	public void setDataIndex(String dataIndex) {
		this.dataIndex = dataIndex;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getHeader() {
		return header;
	}

	public void setHeader(String header) {
		this.header = header;
	}

	public boolean isHidden() {
		return hidden;
	}

	public void setHidden(boolean hidden) {
		this.hidden = hidden;
	}

	public String getOnChange() {
		return onChange;
	}

	public void setOnChange(String onChange) {
		this.onChange = onChange;
	}

	public boolean isSortable() {
		return sortable;
	}

	public void setSortable(boolean sortable) {
		this.sortable = sortable;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getWidth() {
		return width;
	}

	public void setWidth(String width) {
		this.width = width;
	}

	public String getOnClick() {
		return onClick;
	}

	public void setOnClick(String onClick) {
		this.onClick = onClick;
	}

	public String getOnDbClick() {
		return onDbClick;
	}

	public void setOnDbClick(String onDbClick) {
		this.onDbClick = onDbClick;
	}

	public String getSrc() {
		return src;
	}

	public void setSrc(String src) {
		this.src = src;
	}

	public String getStyleClass() {
		return styleClass;
	}

	public void setStyleClass(String styleClass) {
		this.styleClass = styleClass;
	}

	public String getLabelFunction() {
		return labelFunction;
	}

	public void setLabelFunction(String labelFunction) {
		this.labelFunction = labelFunction;
	}

}
