/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui.template;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.web.tag.ui.template.provider.FreemakerUITemplateProvider;

/**
 * JSPTemplateModelRendererFactory
 * 
 * @author leesangboo
 * 
 */
public class UITemplateModelRendererFactory {

	private static final Log log = LogFactory.getLog(UITemplateModelRendererFactory.class);

	private static class JSPTemplateModelRendererFactoryHolder {
		static UITemplateModelRendererFactory instance = new UITemplateModelRendererFactory();
	}

	public static UITemplateModelRendererFactory getInstance() {
		return JSPTemplateModelRendererFactoryHolder.instance;
	}

	private UITemplateModelRenderer render;

	/**
	 * 
	 * @return
	 * @throws DatabaseException
	 */
	public UITemplateModelRenderer getJSPTemplateModelRenderer() throws DatabaseException {
		if (render == null) {
			render = new FreemakerUITemplateProvider();
			log.info("Initialized UI template model renderer for composite view JSP tag library.");
		}
		return render;
	}

}
