/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui.template.provider;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.jdesigner.platform.web.tag.ui.TagConstants;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModel;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModelRenderer;

import freemarker.template.Configuration;
import freemarker.template.ObjectWrapper;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import freemarker.template.TemplateExceptionHandler;

/**
 * UITemplateModelFreemakerRenderer
 * 
 * @author leesangboo
 * 
 */
public class FreemakerUITemplateProvider implements UITemplateModelRenderer {

	/**
	 * HTML을 렌더링 한다.
	 * 
	 * @throws ServletException
	 * @throws IOException
	 */
	public void render(PageContext pageContext, UITemplateModel model) throws ServletException, IOException {
		try {
			//
			Configuration configuration = new Configuration();
			// - Set update dealy to 0 for now, to ease debugging and testing.
			// Higher value should be used in production environment.
			configuration.setServletContextForTemplateLoading(pageContext.getServletContext(), TagConstants.TAG_UI_TEMPATE_PATH);
			//
			configuration.setTemplateUpdateDelay(1000 * 60 * 60 * 24);
			// - cache storage
			// - Set an error handler that prints errors so they are readable
			// with a HTML browser.
			configuration.setTemplateExceptionHandler(TemplateExceptionHandler.RETHROW_HANDLER);
			// - Use beans wrapper (recommmended for most applications)
			configuration.setObjectWrapper(ObjectWrapper.BEANS_WRAPPER);
			// - Set the default charset of the template files
			configuration.setDefaultEncoding("UTF-8");
			// - Set the charset of the output. This is actually just a hint,
			// that
			// templates may require for URL encoding and for generating META
			// element
			// that uses http-equiv="Content-type".
			configuration.setOutputEncoding("UTF-8");
			//

			//
			Template t = configuration.getTemplate(model.getTemplate());
			t.process(model.getRoot(), pageContext.getOut());
			//
		} catch (TemplateException e) {
			throw new ServletException("Error while processing UITemplateModelRenderer :" + e.getMessage(), e);
		}
	}

}
