/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.theme;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.context.ApplicationConfig;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.web.WebConstants;

/**
 * <B>ThemeHandler</B>
 * 
 * @author leesangboo
 * 
 */
public class ThemeHandler {

	private static final Log log = LogFactory.getLog(ThemeHandler.class);

	private static final String DEFAULT_THEME_KEY = "platform.web.theme.theme";

	private static final String THEME_CSS_PATH = "";

	private static final String THEME_IMAGES_DIR_PATH = "/images";

	/**
	 * 테마명을 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public Theme getUserTheme(HttpServletRequest request) {
		return (request.getSession().getAttribute(WebConstants.THEME_KEY) != null) ? (Theme) request.getSession().getAttribute(WebConstants.THEME_KEY) : getDefaultUserTheme();
	}

	/**
	 * 사용자의 기본 설정 테마를 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public Theme getDefaultUserTheme() {
		ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
		ApplicationConfig appConfig = appFactory.getApplicationContext().getApplicationConfig();
		return new Theme(appConfig.getProperty(DEFAULT_THEME_KEY), WebConstants.THEME_RESOURCE_PATH + "/" + appConfig.getProperty(DEFAULT_THEME_KEY) + THEME_CSS_PATH, WebConstants.THEME_RESOURCE_PATH
				+ "/" + appConfig.getProperty(DEFAULT_THEME_KEY) + THEME_IMAGES_DIR_PATH);
	}

	/**
	 * 사용자의 테마를 설정한다.
	 * 
	 * @param request
	 */
	public void setDefaultUserTheme(HttpServletRequest request) {
		setUserTheme(request, null);
	}

	/**
	 * 사용자의 테마를 설정한다.
	 * 
	 * @param request
	 * @param inTheme
	 */
	public void setUserTheme(HttpServletRequest request, Theme inTheme) {
		try {
			HttpSession session = request.getSession();
			Theme outTheme = null;

			if (inTheme == null) {
				outTheme = getDefaultUserTheme();
			} else {
				outTheme = inTheme;
			}
			session.setAttribute(WebConstants.THEME_KEY, outTheme);
		} catch (Exception ex) {
			log.error("Error setting user theme : " + ex.getMessage(), ex);
		}
	}

	/**
	 * 사용자의 테마를 설정한다.
	 * 
	 * @param request
	 * @param inThemeString
	 */
	public Theme stringToTheme(String inThemeString) {
		return new Theme(inThemeString, WebConstants.THEME_RESOURCE_PATH + "/" + inThemeString + THEME_CSS_PATH, WebConstants.THEME_RESOURCE_PATH + "/" + inThemeString + THEME_IMAGES_DIR_PATH);

	}

}
